@@ -241,10 +241,9 @@ applix_sheetref_parse (char const *start, Sheet **sheet, Workbook const *wb)
 		return start;
 	}
 
-	name = g_alloca (1 + end - begin);
-	strncpy (name, begin, end-begin);
-	name [end-begin] = '\0';
+	name = g_strndup (begin, end - begin);
 	*sheet = workbook_sheet_by_name (wb, name);
+	g_free (name);
 	return *sheet != NULL ? end : start;
 }
 
@@ -1012,7 +1011,7 @@ applix_read_view (ApplixReadState *state, unsigned char *buffer)
 			GnmCellPos pos;
 			if (applix_parse_cellref (state, buffer+15, &sheet, &pos, ':') &&
 			    valid_cellpos (sheet, &pos))
-				sv_set_initial_top_left (sheet_get_view (sheet, state->wb_view),
+				gnm_sheet_view_set_initial_top_left (sheet_get_view (sheet, state->wb_view),
 							 pos.col, pos.row);
 		} else if (!a_strncmp (buffer, "View Open Cell: ")) {
 			GnmCellPos pos;
