@@ -358,7 +358,7 @@ dump_missing_functions (void)
 				continue;
 			}
 
-			function_def_count_args (f, &dummy, &dummy);
+			gnm_func_count_args (f, &dummy, &dummy);
 
 			g_warning ("Function %s has args %s.",
 				   name, f->arg_names ? f->arg_names : "?");
@@ -900,6 +900,7 @@ qpro_read_workbook (QProReadState *state, GsfInput *input)
 			if (validate (QPRO_BEGINNING_OF_FILE, 2)) {
 				guint16 version;
 				version = GSF_LE_GET_GUINT16 (data);
+				(void)version;
 			}
 			break;
 		case QPRO_BEGINNING_OF_PAGE:
