@@ -35,12 +35,13 @@
 #include "cellspan.h"
 #include "rendered-value.h"
 #include <goffice/goffice.h>
+#include <string.h>
 
 /* Making ColRowInfo a boxed type to make introspection happy. using no-op
- * functions for copy and free, and  crossing fingers.
+ * functions for copy and free, and crossing fingers.
  */
 static ColRowInfo *
-col_row_info_copy (ColRowInfo *cri)
+col_row_info_fake_copy (ColRowInfo *cri)
 {
 	return cri;
 }
@@ -52,8 +53,8 @@ col_row_info_get_type (void)
 
 	if (t == 0) {
 		t = g_boxed_type_register_static ("ColRowInfo",
-			 (GBoxedCopyFunc)col_row_info_copy,
-			 (GBoxedFreeFunc)col_row_info_copy);
+			 (GBoxedCopyFunc)col_row_info_fake_copy,
+			 (GBoxedFreeFunc)col_row_info_fake_copy);
 	}
 	return t;
 }
@@ -61,7 +62,7 @@ col_row_info_get_type (void)
 double
 colrow_compute_pixel_scale (Sheet const *sheet, gboolean horizontal)
 {
-	return sheet->last_zoom_factor_used *
+	return (sheet ? sheet->last_zoom_factor_used : 1.0) *
 		gnm_app_display_dpi_get (horizontal) / 72.;
 }
 
@@ -74,7 +75,7 @@ colrow_compute_pixels_from_pts (ColRowInfo *cri, Sheet const *sheet,
 	if (scale == -1)
 		scale = colrow_compute_pixel_scale (sheet, horizontal);
 
-	if (horizontal && sheet->display_formulas)
+	if (horizontal && sheet && sheet->display_formulas)
 		scale *= 2;
 
 	cri->size_pixels = (int)(cri->size_pts * scale + 0.5);
@@ -100,21 +101,27 @@ colrow_compute_pts_from_pixels (ColRowInfo *cri, Sheet const *sheet,
 #endif
 }
 
+/**
+ * col_row_info_is_default:
+ * @cri: #ColRowInfo
+ *
+ * %TRUE if @cri is the default style for columns or rows.
+ **/
 gboolean
-colrow_is_default (ColRowInfo const *cri)
+col_row_info_is_default (ColRowInfo const *cri)
 {
 	g_return_val_if_fail (cri != NULL, FALSE);
 	return cri->is_default;
 }
 
 /**
- * colrow_is_empty :
+ * col_row_info_is_empty:
  * @cri: #ColRowInfo
  *
- * TRUE if there is no information in col/row @cri.
+ * %TRUE if there is no information in col/row @cri.
  **/
 gboolean
-colrow_is_empty (ColRowInfo const *cri)
+col_row_info_is_empty (ColRowInfo const *cri)
 {
 	if (cri == NULL)
 		return TRUE;
@@ -125,14 +132,14 @@ colrow_is_empty (ColRowInfo const *cri)
 }
 
 /**
- * colrow_equal :
- * @a: ColRowInfo #1
- * @b: ColRowInfo #2
+ * col_row_info_equal:
+ * @a: First #ColRowInfo
+ * @b: Second #ColRowInfo
  *
- * Returns true if the infos are equivalent.
+ * Returns %TRUE if the infos are equivalent.
  **/
 gboolean
-colrow_equal (ColRowInfo const *a, ColRowInfo const *b)
+col_row_info_equal (ColRowInfo const *a, ColRowInfo const *b)
 {
 	if (a == NULL)
 		return b == NULL;
@@ -147,14 +154,14 @@ colrow_equal (ColRowInfo const *a, ColRowInfo const *b)
 }
 
 /**
- * colrow_copy :
- * @dst:
- * @src:
+ * col_row_info_copy:
+ * @dst: Destination #ColRowInfo
+ * @src: Source #ColRowInfo
  *
- * Assign all content, except the position of @src to @dst
+ * Copy all content, except the position of @src to @dst.
  */
 void
-colrow_copy (ColRowInfo *dst, ColRowInfo const *src)
+col_row_info_copy (ColRowInfo *dst, ColRowInfo const *src)
 {
 	dst->size_pts      = src->size_pts;
 	dst->size_pixels   = src->size_pixels;
@@ -176,52 +183,60 @@ colrow_free (ColRowInfo *cri)
 	g_slice_free1 (sizeof (*cri), cri);
 }
 
+
 /**
- * colrow_foreach:
- * @infos:	The Row or Column collection.
- * @first:	start position (inclusive)
- * @last:	stop column (inclusive)
- * @callback: (scope call): A callback function which should return TRUE to stop
- *              the iteration.
- * @user_data:	A bagage pointer.
+ * colrow_state_list_foreach:
+ * @list: The #ColRowStateList to iterate.
+ * @sheet: (nullable): Origin #Sheet.
+ * @is_cols: %TRUE for columns, %FALSE for rows.
+ * @base: index of first column or row.
+ * @callback: (scope call): A callback function which should
+ *   return %TRUE to stop the iteration.
+ * @user_data:	A baggage pointer.
  *
  * Iterates through the existing rows or columns within the range supplied.
  * Currently only support left -> right iteration.  If a callback returns
- * TRUE iteration stops.
+ * %TRUE iteration stops.
  **/
 gboolean
-colrow_foreach (ColRowCollection const *infos, int first, int last,
-		ColRowHandler callback, gpointer user_data)
+colrow_state_list_foreach (ColRowStateList *list,
+			   Sheet const *sheet, gboolean is_cols,
+			   int base,
+			   ColRowHandler callback,
+			   gpointer user_data)
 {
 	GnmColRowIter iter;
-	ColRowSegment const *segment;
-	int sub, inner_last, i;
+	int i = base;
+	ColRowStateList *l;
+	ColRowInfo cri;
+	double scale = colrow_compute_pixel_scale (sheet, is_cols);
 
-	/* TODO : Do we need to support right -> left as an option */
+	// This sets various fields we do not have
+	memset (&cri, 0, sizeof (cri));
 
-	/* clip */
-	if (last > infos->max_used)
-		last = infos->max_used;
+	iter.cri = &cri;
+	for (l = list; l; l = l->next) {
+		ColRowRLEState *rle = l->data;
+		ColRowState const *state = &rle->state;
+		int l;
 
-	for (i = first; i <= last ; ) {
-		segment = COLROW_GET_SEGMENT (infos, i);
-		sub = COLROW_SUB_INDEX(i);
-		inner_last = (COLROW_SEGMENT_INDEX (last) == COLROW_SEGMENT_INDEX (i))
-			? COLROW_SUB_INDEX (last)+1 : COLROW_SEGMENT_SIZE;
-		iter.pos = i;
-		i += COLROW_SEGMENT_SIZE - sub;
-		if (segment == NULL)
-			continue;
+		cri.size_pts = state->size_pts;
+		cri.outline_level = state->outline_level;
+		cri.is_collapsed = state->is_collapsed;
+		cri.hard_size = state->hard_size;
+		cri.visible = state->visible;
+		colrow_compute_pixels_from_pts (&cri, sheet, is_cols, scale);
 
-		for (; sub < inner_last; sub++, iter.pos++) {
-			iter.cri = segment->info[sub];
-			if (iter.cri != NULL && (*callback)(&iter, user_data))
+		for (l = 0; l < rle->length; l++) {
+			iter.pos = i++;
+			if (iter.cri && (*callback)(&iter, user_data))
 				return TRUE;
 		}
 	}
 	return FALSE;
 }
 
+
 /*****************************************************************************/
 
 typedef struct _ColRowIndex {
@@ -250,7 +265,7 @@ colrow_vis_list_length (ColRowVisList *list)
  * colrow_state_group_destroy:
  * @set: (transfer full): the group to destroy.
  *
- * Returns: (transfer none): %NULL.
+ * Returns: (transfer none) (nullable): %NULL.
  **/
 ColRowStateGroup *
 colrow_state_group_destroy (ColRowStateGroup *group)
@@ -274,8 +289,8 @@ colrow_index_compare (ColRowIndex const * a, ColRowIndex const * b)
  *                              It will be something like : A-B, F-G
  *
  * @list: The list
- * @is_cols: Column index list or row index list?
- * @is_single: If non-null this will be set to TRUE if there's only a single col/row involved.
+ * @is_cols: %TRUE for columns, %FALSE for rows.
+ * @is_single: If non-null this will be set to %TRUE if there's only a single col/row involved.
  */
 GString *
 colrow_index_list_to_string (ColRowIndexList *list, gboolean is_cols, gboolean *is_single)
@@ -379,7 +394,7 @@ colrow_set_single_state (ColRowState *state,
 			 Sheet *sheet, int i, gboolean is_cols)
 {
 	ColRowInfo const *info = sheet_colrow_get_info (sheet, i, is_cols);
-	state->is_default = colrow_is_default (info);
+	state->is_default = col_row_info_is_default (info);
 	state->size_pts	= info->size_pts;
 	state->outline_level = info->outline_level;
 	state->is_collapsed = info->is_collapsed;
@@ -401,11 +416,11 @@ colrow_state_list_destroy (ColRowStateList *list)
 }
 
 /**
- * colrow_get_states:
+ * colrow_get_states: (skip)
  * @sheet: #Sheet
- * @is_cols: %TRUE if columns.
- * @first:
- * @last:
+ * @is_cols: %TRUE for columns, %FALSE for rows.
+ * @first: first column or row.
+ * @last: last column or row.
  *
  * Returns: (transfer full):
  **/
@@ -489,9 +504,9 @@ cb_clear_variable_width_content (GnmCellIter const *iter,
 }
 
 /**
- * colrow_get_sizes:
+ * colrow_get_sizes: (skip)
  * @sheet: #Sheet
- * @is_cols: %TRUE if columns.
+ * @is_cols: %TRUE for columns, %FALSE for rows.
  * @src:
  * @new_size:
  *
@@ -529,9 +544,9 @@ colrow_get_sizes (Sheet *sheet, gboolean is_cols,
 }
 
 /**
- * colrow_set_sizes:
+ * colrow_set_sizes: (skip)
  * @sheet: #Sheet
- * @is_cols:
+ * @is_cols: %TRUE for columns, %FALSE for rows.
  * @src:
  * @new_size:
  * @from:
@@ -554,7 +569,7 @@ colrow_set_sizes (Sheet *sheet, gboolean is_cols,
 		res = g_slist_prepend (res, colrow_get_states (sheet, is_cols,
 			index->first, index->last));
 
-		/* FIXME :
+		/* FIXME:
 		 * If we are changing the size of more than half of the rows/col to
 		 * something specific (not autosize) we should change the default
 		 * row/col size instead.  However, it is unclear how to handle
@@ -576,19 +591,19 @@ colrow_set_sizes (Sheet *sheet, gboolean is_cols,
 			if (is_cols) {
 				rles->state.size_pts = sheet_col_get_default_size_pts (sheet);
 				sheet_col_set_default_size_pixels (sheet, new_size);
-				colrow_foreach (&sheet->cols, 0, gnm_sheet_get_last_col (sheet),
+				sheet_colrow_foreach (sheet, TRUE, 0, -1,
 					&cb_set_colrow_size, &closure);
 			} else {
 				rles->state.size_pts = sheet_row_get_default_size_pts (sheet);
 				sheet_row_set_default_size_pixels (sheet, new_size);
-				colrow_foreach (&sheet->rows, 0, gnm_sheet_get_last_row (sheet),
+				sheet_colrow_foreach (sheet, FALSE, 0, -1,
 					&cb_set_colrow_size, &closure);
 			}
 
 			/* force a re-render of cells with expanding formats */
 			if (is_cols)
-				sheet_foreach_cell_in_range (sheet, CELL_ITER_IGNORE_BLANK,
-					0, 0, gnm_sheet_get_last_col (sheet), gnm_sheet_get_last_row (sheet),
+				sheet_foreach_cell_in_region (sheet, CELL_ITER_IGNORE_BLANK,
+							      0, 0, -1, -1,
 					(CellIterFunc) &cb_clear_variable_width_content, NULL);
 
 			/* Result is a magic 'default' record + >= 1 normal */
@@ -597,8 +612,8 @@ colrow_set_sizes (Sheet *sheet, gboolean is_cols,
 
 		if (is_cols) {
 			/* force a re-render of cells with expanding formats */
-			sheet_foreach_cell_in_range (sheet, CELL_ITER_IGNORE_BLANK,
-				index->first, 0, index->last, gnm_sheet_get_last_row (sheet),
+			sheet_foreach_cell_in_region (sheet, CELL_ITER_IGNORE_BLANK,
+				index->first, 0, index->last, -1,
 				(CellIterFunc) &cb_clear_variable_width_content, NULL);
 
 			/* In order to properly reposition cell comments in
@@ -643,14 +658,15 @@ colrow_set_sizes (Sheet *sheet, gboolean is_cols,
 	return res;
 }
 
-/*
- * NOTE : this is a low level routine it does not redraw or
- *        reposition objects
+/**
+ * colrow_set_states: (skip)
+ * @sheet: #Sheet
+ * @is_cols: %TRUE for columns, %FALSE for rows.
+ * @first: first column or row
+ * @states: saved state to restore.
  *
- * NOTE : this does not delete states any longer since it may be used
- *        for several sheets.
+ * This is a low level routine it does not redraw or reposition objects
  */
-
 void
 colrow_set_states (Sheet *sheet, gboolean is_cols,
 		   int first, ColRowStateList *states)
@@ -689,7 +705,7 @@ colrow_set_states (Sheet *sheet, gboolean is_cols,
 				cri->hard_size = state->hard_size;
 				cri->size_pts = state->size_pts;
 				colrow_compute_pixels_from_pts (cri, sheet, is_cols, scale);
-				colrow_set_outline (cri, state->outline_level,
+				col_row_info_set_outline (cri, state->outline_level,
 					state->is_collapsed);
 			}
 		}
@@ -718,6 +734,14 @@ colrow_set_states (Sheet *sheet, gboolean is_cols,
 	sheet_colrow_gutter (sheet, is_cols, max_outline);
 }
 
+/**
+ * colrow_restore_state_group: (skip)
+ * @sheet: #Sheet
+ * @is_cols: %TRUE for columns, %FALSE for rows.
+ * @selection:
+ * @state_groups:
+ *
+ **/
 void
 colrow_restore_state_group (Sheet *sheet, gboolean is_cols,
 			    ColRowIndexList *selection,
@@ -748,8 +772,8 @@ colrow_restore_state_group (Sheet *sheet, gboolean is_cols,
 		colrow_set_states (sheet, is_cols, index->first, ptr->data);
 		/* force a re-render of cells with expanding formats */
 		if (is_cols)
-			sheet_foreach_cell_in_range (sheet, CELL_ITER_IGNORE_BLANK,
-				index->first, 0, index->last, gnm_sheet_get_last_row (sheet),
+			sheet_foreach_cell_in_region (sheet, CELL_ITER_IGNORE_BLANK,
+				index->first, 0, index->last, -1,
 				(CellIterFunc) &cb_clear_variable_width_content, NULL);
 		selection = selection->prev;
 	}
@@ -759,15 +783,15 @@ colrow_restore_state_group (Sheet *sheet, gboolean is_cols,
  * rows_height_update:
  * @sheet:  The sheet,
  * @range:  The range whose rows should be resized.
- * @shrink: If set to FALSE, rows will never shrink!
+ * @shrink: If set to %FALSE, rows will never shrink!
  *
- * Use this function having changed the font size to auto
- * resize the row heights to make the text fit nicely.
+ * Use this function having changed the font size to auto-resize the row
+ * heights to make the text fit nicely.
  **/
 void
-rows_height_update (Sheet *sheet, GnmRange const * range, gboolean shrink)
+rows_height_update (Sheet *sheet, GnmRange const *range, gboolean shrink)
 {
-	/* FIXME : this needs to check font sizes and contents rather than
+	/* FIXME: this needs to check font sizes and contents rather than
 	 * just contents.  Empty cells will cause resize also */
 	colrow_autofit (sheet, range, FALSE, FALSE,
 			FALSE, !shrink,
@@ -841,14 +865,16 @@ cb_autofit_row (GnmColRowIter const *iter, gpointer data_)
 
 /*
  * colrow_autofit:
- * @sheet: the sheet to change
+ * @sheet: the #Sheet to change
  * @range: the range to consider
- * @is_cols: TRUE for columns, FALSE for rows.
+ * @is_cols: %TRUE for columns, %FALSE for rows.
  * @ignore_strings: Don't consider cells with string values.
  * @min_current: Don't shrink below current size.
  * @min_default: Don't shrink below default size.
- * @indices: indices appropriate for colrow_restore_state_group.
- * @sizes: old sizes appropriate for colrow_restore_state_group.
+ * @indices: (out) (optional): indices appropriate for
+ *     colrow_restore_state_group.
+ * @sizes: (out) (optional): old sizes appropriate for
+ *     colrow_restore_state_group.
  *
  * This function autofits columns or rows in @range as specified by
  * @is_cols.  Only cells in @range are considered for the sizing
@@ -864,7 +890,6 @@ colrow_autofit (Sheet *sheet, const GnmRange *range, gboolean is_cols,
 {
 	struct cb_autofit data;
 	int a, b;
-	ColRowCollection *crs;
 	ColRowHandler handler;
 
 	data.sheet = sheet;
@@ -876,12 +901,10 @@ colrow_autofit (Sheet *sheet, const GnmRange *range, gboolean is_cols,
 	if (is_cols) {
 		a = range->start.col;
 		b = range->end.col;
-		crs = &sheet->cols;
 		handler = cb_autofit_col;
 	} else {
 		a = range->start.row;
 		b = range->end.row;
-		crs = &sheet->rows;
 		handler = cb_autofit_row;
 	}
 
@@ -894,22 +917,32 @@ colrow_autofit (Sheet *sheet, const GnmRange *range, gboolean is_cols,
 	   stuff that caches sub-computations see the whole thing instead
 	   of clearing between cells.  */
 	gnm_app_recalc_start ();
-	colrow_foreach (crs, a, b, handler, &data);
+	sheet_colrow_foreach (sheet, is_cols, a, b, handler, &data);
 	gnm_app_recalc_finish ();
 }
 
+/**
+ * colrow_autofit_col:
+ * @sheet: the #Sheet to change
+ * @r: the range to consider
+ */
 void
 colrow_autofit_col (Sheet *sheet, GnmRange *r)
 {
 	colrow_autofit (sheet, r, TRUE, TRUE,
 			TRUE, FALSE, NULL, NULL);
-	sheet_foreach_cell_in_range (sheet, CELL_ITER_IGNORE_BLANK,
-				     r->start.col, 0,
-				     r->end.col, gnm_sheet_get_last_row (sheet),
-				     (CellIterFunc) &cb_clear_variable_width_content,
-				     NULL);
+	sheet_foreach_cell_in_region (sheet, CELL_ITER_IGNORE_BLANK,
+				      r->start.col, 0,
+				      r->end.col, -1,
+				      (CellIterFunc) &cb_clear_variable_width_content,
+				      NULL);
 }
 
+/**
+ * colrow_autofit_row:
+ * @sheet: the #Sheet to change
+ * @r: the range to consider
+ */
 void
 colrow_autofit_row (Sheet *sheet, GnmRange *r)
 {
@@ -923,7 +956,7 @@ typedef struct
 {
 	gboolean is_cols, visible;
 	ColRowVisList *elements;
-} ColRowVisiblity;
+} ColRowVisibility;
 
 static gint
 colrow_index_cmp (ColRowIndex const *a, ColRowIndex const *b)
@@ -933,7 +966,7 @@ colrow_index_cmp (ColRowIndex const *a, ColRowIndex const *b)
 }
 
 static void
-colrow_visibility (Sheet const *sheet, ColRowVisiblity * const dat,
+colrow_visibility (Sheet const *sheet, ColRowVisibility * const dat,
 		   int first, int last)
 {
 	int i;
@@ -985,9 +1018,9 @@ colrow_visibility (Sheet const *sheet, ColRowVisiblity * const dat,
 }
 
 /**
- * colrow_get_outline_toggle:
+ * colrow_get_outline_toggle: (skip)
  * @sheet: #Sheet
- * @is_cols:
+ * @is_cols: %TRUE for columns, %FALSE for rows.
  * @visible:
  * @first:
  * @last:
@@ -998,7 +1031,7 @@ ColRowVisList *
 colrow_get_outline_toggle (Sheet const *sheet, gboolean is_cols, gboolean visible,
 			   int first, int last)
 {
-	ColRowVisiblity closure;
+	ColRowVisibility closure;
 	closure.is_cols = is_cols;
 	closure.visible = visible;
 	closure.elements = NULL;
@@ -1010,7 +1043,7 @@ colrow_get_outline_toggle (Sheet const *sheet, gboolean is_cols, gboolean visibl
 static void
 cb_colrow_visibility (SheetView *sv, GnmRange const *r, gpointer closure)
 {
-	ColRowVisiblity * const dat = (ColRowVisiblity *)closure;
+	ColRowVisibility * const dat = (ColRowVisibility *)closure;
 	int first, last;
 
 	if (dat->is_cols) {
@@ -1024,24 +1057,21 @@ cb_colrow_visibility (SheetView *sv, GnmRange const *r, gpointer closure)
 }
 
 /**
- * colrow_get_visiblity_toggle:
+ * colrow_get_visibility_toggle: (skip)
  * @sv: The sheet view whose selection we are interested in.
- * @is_cols: A flag indicating whether this it is a column or a row.
+ * @is_cols: %TRUE for columns, %FALSE for rows.
  * @visible: Should we unhide or hide the cols/rows.
  *
  * Searches the selection list and generates a list of index,count
  * pairs of row/col ranges that need to be hidden or unhiden.
  *
- * NOTE : leave sheet non-const until we have a const version of
- *        sv_selection_apply.
- *
  * Returns: (transfer full): the list.
  */
 ColRowVisList *
-colrow_get_visiblity_toggle (SheetView *sv, gboolean is_cols,
+colrow_get_visibility_toggle (SheetView *sv, gboolean is_cols,
 			     gboolean visible)
 {
-	ColRowVisiblity closure;
+	ColRowVisibility closure;
 	closure.is_cols = is_cols;
 	closure.visible = visible;
 	closure.elements = NULL;
@@ -1051,8 +1081,11 @@ colrow_get_visiblity_toggle (SheetView *sv, gboolean is_cols,
 	return closure.elements;
 }
 
-/*
- * colrow_set_visibility_list :
+/**
+ * colrow_set_visibility_list:
+ * @sheet: The #Sheet to change
+ * @is_cols: %TRUE for columns, %FALSE for rows.
+ * @visible: Should we unhide or hide the cols/rows.
  *
  * This is the high level command that is wrapped by undo and redo.
  * It should not be called by other commands.
@@ -1080,24 +1113,24 @@ colrow_set_visibility_list (Sheet *sheet, gboolean is_cols,
 }
 
 /**
- * colrow_set_outline :
- * @cri: the col/row to tweak
+ * col_row_info_set_outline:
+ * @cri: #ColRowInfo to tweak
  * @outline_level:
  * @is_collapsed:
  *
  * Adjust the outline state of a col/row
  */
 void
-colrow_set_outline (ColRowInfo *cri, int outline_level, gboolean is_collapsed)
+col_row_info_set_outline (ColRowInfo *cri, int outline_level, gboolean is_collapsed)
 {
 	g_return_if_fail (outline_level >= 0);
 
-	cri->is_collapsed = (is_collapsed != 0);  /* be anal */
+	cri->is_collapsed = !!is_collapsed;
 	cri->outline_level = outline_level;
 }
 
 /**
- * colrow_find_outline_bound :
+ * colrow_find_outline_bound:
  *
  * find the next/prev col/row at the designated depth starting from the
  * supplied @index.
@@ -1128,8 +1161,8 @@ colrow_find_outline_bound (Sheet const *sheet, gboolean is_cols,
 
 /**
  * colrow_set_visibility:
- * @sheet: the sheet
- * @is_cols: Are we dealing with rows or columns.
+ * @sheet: the #Sheet
+ * @is_cols: %TRUE for columns, %FALSE for rows.
  * @visible: Make things visible or invisible.
  * @first: The index of the first row/col (inclusive)
  * @last: The index of the last row/col (inclusive)
@@ -1216,22 +1249,27 @@ colrow_set_visibility (Sheet *sheet, gboolean is_cols,
 	}
 
 	if (changed && 0 <= i && i < colrow_max (is_cols, sheet)) {
-		ColRowInfo * const cri = sheet_colrow_fetch (sheet, i, is_cols);
-		if (prev_outline > cri->outline_level)
+		ColRowInfo *cri = sheet_colrow_get (sheet, i, is_cols);
+		if (!cri && !visible && prev_outline > 0)
+			cri = sheet_colrow_fetch (sheet, i, is_cols);
+
+		if (cri && prev_outline > cri->outline_level)
 			cri->is_collapsed = !visible;
 	}
 }
 
-/**
- * colrow_get_global_outline :
+// Introspection scanner crashes if the following "hide" is removed.
+
+/*hide*
+ * colrow_get_global_outline: (skip)
  * @sheet:
- * @is_cols:
+ * @is_cols: %TRUE for columns, %FALSE for rows.
  * @depth:
- * @show:
- * @hide:
+ * @show: (out):
+ * @hide: (out):
  *
- * Collect the set of visiblity changes required to change the visiblity of
- * all outlined columns such tach those > @depth are visible.
+ * Collect the set of visibility changes required to change the visibility of
+ * all outlined columns such that those > @depth are visible.
  **/
 void
 colrow_get_global_outline (Sheet const *sheet, gboolean is_cols, int depth,
@@ -1256,7 +1294,7 @@ colrow_get_global_outline (Sheet const *sheet, gboolean is_cols, int depth,
 
 		/* see what sort of changes are necessary and do simple run
 		 * length encoding.  Do not be too efficent, we need to change
-		 * the visiblity per outline level or the collapse state
+		 * the visibility per outline level or the collapse state
 		 * change in colrow_set_visibility is missed. */
 		if (cri->outline_level < depth) {
 			if (cri->visible)
@@ -1288,21 +1326,3 @@ colrow_get_global_outline (Sheet const *sheet, gboolean is_cols, int depth,
 	*show = g_slist_reverse (*show);
 	*hide = g_slist_reverse (*hide);
 }
-
-void
-colrow_resize (ColRowCollection *infos, int size)
-{
-	int end_idx = COLROW_SEGMENT_INDEX (size);
-	int i = infos->info->len - 1;
-
-	while (i >= end_idx) {
-		ColRowSegment *segment = g_ptr_array_index (infos->info, i);
-		if (segment) {
-			g_free (segment);
-			g_ptr_array_index (infos->info, i) = NULL;
-		}
-		i--;
-	}
-
-	g_ptr_array_set_size (infos->info, end_idx);
-}
