@@ -400,8 +400,7 @@ parse_criteria_range (Sheet *sheet, int b_col, int b_row, int e_col, int e_row,
 		      int   *field_ind, gboolean anchor_end)
 {
 	GSList *criterias = NULL;
-	GODateConventions const *date_conv =
-		workbook_date_conv (sheet->workbook);
+	GODateConventions const *date_conv = sheet_date_conv (sheet);
         int i, j;
 
 	for (i = b_row; i <= e_row; i++) {
@@ -494,7 +493,7 @@ parse_database_criteria (GnmEvalPos const *ep, GnmValue const *database, GnmValu
  * @first_col: first column.
  * @first_row: first row.
  * @last_col: last column.
- * @last_row: laset row.
+ * @last_row: last row.
  * @criterias: (element-type GnmDBCriteria): the criteria to use.
  * @unique_only:
  *
@@ -535,15 +534,13 @@ find_rows_that_match (Sheet *sheet, int first_col, int first_row,
 				break;
 		}
 		if (add_flag) {
-			gint *p;
-
 			if (unique_only) {
 				GSList *c;
 				GnmCell   *cell;
-				gint    i, trow;
+				gint    i;
 
 				for (c = rows; c != NULL; c = c->next) {
-					trow = *((gint *) c->data);
+					int trow = GPOINTER_TO_INT (c->data);
 					for (i = first_col; i <= last_col; i++) {
 						test_cell = sheet_cell_get (sheet, i, trow);
 						cell = sheet_cell_get (sheet, i, row);
@@ -566,9 +563,7 @@ row_ok:
 					;
 				}
 			}
-			p = g_new (gint, 1);
-			*p = row;
-			rows = g_slist_prepend (rows, (gpointer) p);
+			rows = g_slist_prepend (rows, GINT_TO_POINTER (row));
 filter_row:
 			;
 		}
