@@ -150,6 +150,8 @@ typedef struct {
 
 } DialogDocMetaData;
 
+#define trim_string(s_) g_strstrip (g_strdup ((s_)))
+
 static gchar *dialog_doc_metadata_get_prop_val (DialogDocMetaData *state, char const *prop_name,
 						GValue *prop_value);
 
@@ -775,7 +777,7 @@ static void
 dialog_doc_metadata_add_prop (DialogDocMetaData *state,
 			      const gchar       *name,
 			      const gchar       *value,
-			      const gchar       *link,
+			      const gchar       *lnk,
 			      GType              val_type)
 {
 	gboolean editable = (val_type != G_TYPE_INVALID)
@@ -783,14 +785,14 @@ dialog_doc_metadata_add_prop (DialogDocMetaData *state,
 	if (value == NULL)
 		value = "";
 
-	if (link == NULL)
-		link = "";
+	if (lnk == NULL)
+		lnk = "";
 
 	/* Append new values in tree view */
 	gtk_tree_store_insert_with_values (state->properties_store, NULL, NULL, G_MAXINT,
 					   0, name,
 					   1, value,
-					   2, link,
+					   2, lnk,
 					   3, editable,
 					   4, val_type,
 					   -1);
@@ -870,7 +872,7 @@ dialog_doc_metadata_set_gsf_prop_val (DialogDocMetaData *state,
  * @state: dialog main struct
  * @name: property name
  * @value: property value
- * @link: property linked to
+ * @lnk: property linked to
  *
  * Sets a new value to the property in the GsfDocMetaData struct
  *
@@ -879,7 +881,7 @@ static GType
 dialog_doc_metadata_set_gsf_prop (DialogDocMetaData *state,
 				  const gchar       *name,
 				  const gchar       *value,
-				  const gchar       *link,
+				  const gchar       *lnk,
 				  GType              type)
 {
 	GsfDocProp *existing_prop = NULL;
@@ -894,16 +896,16 @@ dialog_doc_metadata_set_gsf_prop (DialogDocMetaData *state,
 		existing_link  = gsf_doc_prop_get_link (existing_prop);
 	}
 
-	if (link != NULL && *link == 0)
-		link = NULL;
+	if (lnk != NULL && *lnk == 0)
+		lnk = NULL;
 	if (value != NULL && *value == 0)
 		value = NULL;
-	if ((value == NULL) && (link == NULL)) {
+	if ((value == NULL) && (lnk == NULL)) {
 		if ((existing_prop == NULL) ||
 		    ((existing_value == NULL) && (existing_link == NULL)))
 			return G_TYPE_INVALID;
 		else {
-			cmd_change_meta_data (WORKBOOK_CONTROL (state->wbcg), NULL,
+			cmd_change_meta_data (GNM_WBC (state->wbcg), NULL,
 					      g_slist_prepend (NULL, g_strdup (name)));
 			return G_TYPE_INVALID;
 		}
@@ -915,12 +917,12 @@ dialog_doc_metadata_set_gsf_prop (DialogDocMetaData *state,
 
 		if (existing_link!= NULL && *existing_link == 0)
 			existing_link = NULL;
-		if (link == existing_link)
+		if (lnk == existing_link)
 			link_changed = FALSE;
-		else if (link == NULL || existing_link == NULL)
+		else if (lnk == NULL || existing_link == NULL)
 			link_changed = TRUE;
 		else
-			link_changed = (0 != strcmp (link, existing_link));
+			link_changed = (0 != strcmp (lnk, existing_link));
 
 		if (existing_value == NULL)
 			value_changed = (value != NULL);
@@ -959,10 +961,10 @@ dialog_doc_metadata_set_gsf_prop (DialogDocMetaData *state,
 		gsf_doc_prop_set_val (doc_prop, doc_prop_value);
 	}
 
-	if (link != NULL)
-		gsf_doc_prop_set_link (doc_prop, g_strdup (link));
+	if (lnk != NULL)
+		gsf_doc_prop_set_link (doc_prop, g_strdup (lnk));
 
-	cmd_change_meta_data (WORKBOOK_CONTROL (state->wbcg),
+	cmd_change_meta_data (GNM_WBC (state->wbcg),
 			      g_slist_prepend (NULL, doc_prop), NULL);
 
 	return val_type;
@@ -1411,7 +1413,7 @@ cb_dialog_doc_metadata_add_clicked (G_GNUC_UNUSED GtkWidget *w,
 {
 	const gchar *name = gtk_entry_get_text (state->ppt_name);
 	const gchar *value = gtk_entry_get_text (state->ppt_value);
-	gchar *name_trimmed = pango_trim_string (name);
+	gchar *name_trimmed = trim_string (name);
 	GType t;
 	GtkTreeIter filter_iter;
 
@@ -1554,7 +1556,7 @@ cb_dialog_doc_metadata_remove_clicked (GtkWidget         *remove_bt,
 						 NULL, NULL);
 
 		/* Remove property from GsfMetadata */
-		cmd_change_meta_data (WORKBOOK_CONTROL (state->wbcg), NULL,
+		cmd_change_meta_data (GNM_WBC (state->wbcg), NULL,
 				      g_slist_prepend (NULL, g_value_dup_string (prop_name)));
 
 		/* Remove from Tree View */
@@ -1744,7 +1746,7 @@ cb_dialog_doc_metadata_ppt_changed (G_GNUC_UNUSED GtkEntry          *entry,
 
 	name = gtk_entry_get_text (state->ppt_name);
 	value = gtk_entry_get_text (state->ppt_value);
-	name_trimmed = pango_trim_string (name);
+	name_trimmed = trim_string (name);
 
 	enable = strlen (name_trimmed) > 0 && strlen (value) > 0;
 
@@ -1786,7 +1788,7 @@ cb_dialog_doc_metadata_ppt_name_changed (G_GNUC_UNUSED GtkEntry          *entry,
 	gchar *str = NULL;
 
 	name = gtk_entry_get_text (state->ppt_name);
-	name_trimmed = pango_trim_string (name);
+	name_trimmed = trim_string (name);
 
 	enable = strlen (name_trimmed) > 0;
 
@@ -2109,7 +2111,7 @@ dialog_doc_metadata_set_file_permissions (DialogDocMetaData *state)
 static void
 dialog_doc_metadata_free (DialogDocMetaData *state)
 {
-	WorkbookControl *wbc = WORKBOOK_CONTROL (state->wbcg);
+	WorkbookControl *wbc = GNM_WBC (state->wbcg);
 
 	wb_view_selection_desc (wb_control_view (wbc), TRUE, wbc);
 
@@ -2312,9 +2314,9 @@ dialog_doc_metadata_init (DialogDocMetaData *state,
 	int i;
 
 	state->wbcg     = wbcg;
-	state->wb       = wb_control_get_workbook (WORKBOOK_CONTROL(wbcg));
+	state->wb       = wb_control_get_workbook (GNM_WBC(wbcg));
 	state->doc      = GO_DOC (state->wb);
-	state->metadata = go_doc_get_meta_data (wb_control_get_doc (WORKBOOK_CONTROL (state->wbcg)));
+	state->metadata = go_doc_get_meta_data (wb_control_get_doc (GNM_WBC (state->wbcg)));
 
 	g_return_val_if_fail (state->metadata  != NULL, TRUE);
 
@@ -2395,7 +2397,7 @@ dialog_doc_metadata_init (DialogDocMetaData *state,
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (state->store), ITEM_NAME, GTK_SORT_ASCENDING);
 
 	/* A candidate for merging into attach guru */
-	gnumeric_keyed_dialog (state->wbcg,
+	gnm_keyed_dialog (state->wbcg,
 			       GTK_WINDOW (state->dialog),
 			       DOC_METADATA_KEY);
 
@@ -2408,7 +2410,7 @@ dialog_doc_metadata_init (DialogDocMetaData *state,
 		state, (GDestroyNotify) dialog_doc_metadata_free);
 
 	/* Help and Close buttons */
-	gnumeric_init_help_button (GTK_WIDGET (state->help_button),
+	gnm_init_help_button (GTK_WIDGET (state->help_button),
 				   GNUMERIC_HELP_LINK_METADATA);
 
 	g_signal_connect_swapped (G_OBJECT (state->close_button),
@@ -2445,7 +2447,7 @@ dialog_doc_metadata_new (WBCGtk *wbcg, int page)
 		return;
 
 	/* Only pop up one copy per workbook */
-	if (gnumeric_dialog_raise_if_exists (wbcg, DOC_METADATA_KEY))
+	if (gnm_dialog_raise_if_exists (wbcg, DOC_METADATA_KEY))
 		return;
 
 	state = g_new0 (DialogDocMetaData, 1);
