@@ -18,8 +18,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
@@ -74,7 +73,7 @@ enum {
 	SHEET_NAME,
 	SHEET_POINTER,
 	EXPRESSION,
-	NUM_COLMNS
+	NUM_COLUMNS
 };
 
 static void
@@ -370,7 +369,7 @@ dialog_goto_init (GotoState *state)
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
 					     GTK_SHADOW_ETCHED_IN);
 
-	state->model = gtk_tree_store_new (NUM_COLMNS, G_TYPE_STRING,
+	state->model = gtk_tree_store_new (NUM_COLUMNS, G_TYPE_STRING,
 					   G_TYPE_STRING, G_TYPE_POINTER,
 					   G_TYPE_POINTER);
 	state->treeview = GTK_TREE_VIEW (
