@@ -30,7 +30,6 @@
 #include <selection.h>
 #include <expr.h>
 #include <expr-deriv.h>
-#include <expr-impl.h>
 #include <sheet.h>
 #include <cell.h>
 #include <application.h>
@@ -162,6 +161,7 @@ gnumeric_table_link (GnmFuncEvalInfo *ei, gboolean qlink)
 {
 	GnmDependent *dep = ei->pos->dep;
 	GnmRangeRef rr;
+	int cols, rows;
 
 	if (!qlink)
 		return DEPENDENT_NO_FLAG;
@@ -169,6 +169,8 @@ gnumeric_table_link (GnmFuncEvalInfo *ei, gboolean qlink)
 	if (!eval_pos_is_array_context (ei->pos))
 		return DEPENDENT_IGNORE_ARGS;
 
+	gnm_expr_top_get_array_size (ei->pos->array_texpr, &cols, &rows);
+
 	rr.a.col_relative = rr.a.row_relative =
 	rr.b.col_relative = rr.b.row_relative = FALSE;
 	rr.a.sheet = rr.b.sheet = dep->sheet;
@@ -176,13 +178,13 @@ gnumeric_table_link (GnmFuncEvalInfo *ei, gboolean qlink)
 	g_return_val_if_fail (ei->pos->eval.col > 0, DEPENDENT_IGNORE_ARGS);
 	rr.a.col = rr.b.col = ei->pos->eval.col - 1;
 	rr.a.row = ei->pos->eval.row;
-	rr.b.row = rr.a.row + ei->pos->array->rows - 1;
+	rr.b.row = rr.a.row + rows - 1;
 	dependent_add_dynamic_dep (dep, &rr);
 
 	g_return_val_if_fail (ei->pos->eval.row > 0, DEPENDENT_IGNORE_ARGS);
 	rr.a.row = rr.b.row = ei->pos->eval.row - 1;
 	rr.a.col = ei->pos->eval.col;
-	rr.b.col = rr.a.col + ei->pos->array->cols - 1;
+	rr.b.col = rr.a.col + cols - 1;
 	dependent_add_dynamic_dep (dep, &rr);
 
 	return DEPENDENT_IGNORE_ARGS;
@@ -196,6 +198,7 @@ gnumeric_table (GnmFuncEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
 	GnmCellPos     pos;
 	GnmEvalPos const *ep = ei->pos;
 	int x, y;
+	int cols, rows;
 
 	/* evaluation clears the dynamic deps */
 	gnumeric_table_link (ei, TRUE);
@@ -208,12 +211,12 @@ gnumeric_table (GnmFuncEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
 
 	for (x = 0; x < 2 ; x++) {
 		GnmExpr const *arg = argv[x];
+		GnmCellRef const *cr = arg ? gnm_expr_get_cellref (arg) : NULL;
 		in[x] = NULL;
 		val[x] = NULL;
 
-		if (arg && GNM_EXPR_GET_OPER (arg) == GNM_EXPR_OP_CELLREF) {
-			gnm_cellpos_init_cellref (&pos,	&arg->cellref.ref,
-						  &ep->eval, ep->sheet);
+		if (cr) {
+			gnm_cellpos_init_cellref (&pos,	cr, &ep->eval, ep->sheet);
 			in[x] = sheet_cell_get (ep->sheet, pos.col, pos.row);
 			if (NULL == in[x])
 				in[x] = sheet_cell_fetch (ep->sheet, pos.col, pos.row);
@@ -238,8 +241,10 @@ gnumeric_table (GnmFuncEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
 			val[2] = value_dup (in[2]->value);
 	}
 
-	res = value_new_array (ep->array->cols, ep->array->rows);
-	for (x = ep->array->cols ; x-- > 0 ; ) {
+	gnm_expr_top_get_array_size (ei->pos->array_texpr, &cols, &rows);
+
+	res = value_new_array (cols, rows);
+	for (x = cols ; x-- > 0 ; ) {
 		x_iter = sheet_cell_get (ep->sheet,
 			x + ep->eval.col, ep->eval.row-1);
 		if (NULL == x_iter)
@@ -256,7 +261,7 @@ gnumeric_table (GnmFuncEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
 			val[0] = value_dup (x_iter->value);
 		}
 
-		for (y = ep->array->rows ; y-- > 0 ; ) {
+		for (y = rows ; y-- > 0 ; ) {
 			g_signal_emit_by_name (gnm_app_get_app (), "recalc-finished");
 			y_iter = sheet_cell_get (ep->sheet,
 				ep->eval.col-1, y + ep->eval.row);
@@ -357,7 +362,7 @@ gnumeric_if (GnmFuncEvalInfo *ei, GnmValue const * const *args)
 	if (args[res])
 		return value_dup (args[res]);
 
-	if (ei->func_call->argc < res + 1)
+	if (gnm_eval_info_get_arg_count (ei) < res + 1)
 		/* arg-not-there: default to TRUE/FALSE.  */
 		return value_new_bool (res == 1);
 	else
@@ -453,7 +458,7 @@ void
 func_builtin_init (void)
 {
 	const char *gname;
-	const char *textdomain = GETTEXT_PACKAGE;
+	const char *tdomain = GETTEXT_PACKAGE;
 	int i = 0;
 
 	static GnmFuncDescriptor const builtins [] = {
@@ -502,20 +507,20 @@ func_builtin_init (void)
 
 	gname = N_("Mathematics");
 	math_group = gnm_func_group_fetch (gname, _(gname));
-	gnm_func_add (math_group, builtins + i++, textdomain);
-	gnm_func_add (math_group, builtins + i++, textdomain);
+	gnm_func_add (math_group, builtins + i++, tdomain);
+	gnm_func_add (math_group, builtins + i++, tdomain);
 
 	gname = N_("Gnumeric");
 	gnumeric_group = gnm_func_group_fetch (gname, _(gname));
-	gnm_func_add (gnumeric_group, builtins + i++, textdomain);
-	gnm_func_add (gnumeric_group, builtins + i++, textdomain);
+	gnm_func_add (gnumeric_group, builtins + i++, tdomain);
+	gnm_func_add (gnumeric_group, builtins + i++, tdomain);
 	if (gnm_debug_flag ("testsuite"))
-		gnm_func_add (gnumeric_group, builtins + i, textdomain);
+		gnm_func_add (gnumeric_group, builtins + i, tdomain);
 	i++;
 
 	gname = N_("Logic");
 	logic_group = gnm_func_group_fetch (gname, _(gname));
-	gnm_func_add (logic_group, builtins + i++, textdomain);
+	gnm_func_add (logic_group, builtins + i++, tdomain);
 
 	gnm_expr_deriv_install_handler (gnm_func_lookup ("sum", NULL),
 					gnumeric_sum_deriv,
