@@ -84,7 +84,7 @@ static gboolean
 gnm_pane_object_key_press (GnmPane *pane, GdkEventKey *ev)
 {
 	SheetControlGUI *scg = pane->simple.scg;
-	SheetControl    *sc = GNM_SC (scg);
+	SheetControl    *sc = GNM_SHEET_CONTROL (scg);
 	gboolean const shift	= 0 != (ev->state & GDK_SHIFT_MASK);
 	gboolean const control	= 0 != (ev->state & GDK_CONTROL_MASK);
 	gboolean const alt	= 0 != (ev->state & GDK_MOD1_MASK);
@@ -358,12 +358,12 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *kevent,
 			wbcg_set_end_mode (wbcg, !end_mode);
 		break;
 
-	case GDK_KEY_KP_Insert :
-	case GDK_KEY_Insert :
+	case GDK_KEY_KP_Insert:
+	case GDK_KEY_Insert:
 		if (gnm_pane_guru_key (wbcg, event))
 			break;
 		if (state == GDK_CONTROL_MASK)
-			sv_selection_copy (sv, GNM_WBC (wbcg));
+			gnm_sheet_view_selection_copy (sv, GNM_WBC (wbcg));
 		else if (state == GDK_SHIFT_MASK)
 			cmd_paste_to_selection (GNM_WBC (wbcg), sv, PASTE_DEFAULT);
 		break;
@@ -394,7 +394,7 @@ gnm_pane_key_mode_sheet (GnmPane *pane, GdkEventKey *kevent,
 			break;
 		if (state == GDK_SHIFT_MASK) {
 			scg_mode_edit (scg);
-			sv_selection_cut (sv, GNM_WBC (wbcg));
+			gnm_sheet_view_selection_cut (sv, GNM_WBC (wbcg));
 		} else
 			cmd_selection_clear (GNM_WBC (wbcg), CLEAR_VALUES);
 		break;
@@ -1474,7 +1474,7 @@ gnm_pane_compute_visible_region (GnmPane *pane,
 
 	/* Update the scrollbar sizes for the primary pane */
 	if (pane->index == 0)
-		sc_scrollbar_config (GNM_SC (scg));
+		sc_scrollbar_config (GNM_SHEET_CONTROL (scg));
 
 	/* Force the cursor to update its bounds relative to the new visible region */
 	gnm_pane_reposition_cursors (pane);
@@ -2509,7 +2509,7 @@ control_point_set_cursor (SheetControlGUI const *scg, GocItem *ctrl_pt)
 		break;
 
 	case 8:
-	default :
+	default:
 		cursor = GDK_FLEUR;
 	}
 	gnm_widget_set_cursor_type (GTK_WIDGET (ctrl_pt->canvas), cursor);
@@ -2741,7 +2741,7 @@ control_point_button2_pressed (GocItem *item, int button, G_GNUC_UNUSED double x
 
 	so  = g_object_get_data (G_OBJECT (item), "so");
 	if (pane->drag.button == 1)
-		sheet_object_get_editor (so, GNM_SC (scg));
+		sheet_object_get_editor (so, GNM_SHEET_CONTROL (scg));
 	return TRUE;
 }
 
