@@ -1,6 +1,6 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * gnm-sheet-slicer.c :
+ * gnm-sheet-slicer.c:
  *
  * Copyright (C) 2008-2009 Jody Goldberg (jody@gnome.org)
  *
@@ -53,7 +53,7 @@ struct _GnmSheetSlicer {
 typedef GODataSlicerClass GnmSheetSlicerClass;
 
 #define GNM_SHEET_SLICER_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST ((k), GNM_SHEET_SLICER_TYPE, GnmSheetSlicerClass))
-#define IS_GNM_SHEET_SLICER_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), GNM_SHEET_SLICER_TYPE))
+#define GNM_IS_SHEET_SLICER_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), GNM_SHEET_SLICER_TYPE))
 #define GNM_SHEET_SLICER_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GNM_SHEET_SLICER_TYPE, GnmSheetSlicerClass))
 
 enum {
@@ -190,7 +190,7 @@ gnm_sheet_slicer_class_init (GnmSheetSlicerClass *klass)
 			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 
 	g_object_class_install_property (gobject_class, PROP_LAYOUT,
-		 g_param_spec_enum ("layout", NULL, NULL, gnm_sheet_slicer_layout_get_type (), GSS_Layout_XL_outline,
+		 g_param_spec_enum ("layout", NULL, NULL, gnm_sheet_slicer_layout_get_type (), GSS_LAYOUT_XL_OUTLINE,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	parent_klass = g_type_class_peek_parent (klass);
 }
@@ -203,7 +203,7 @@ void
 gnm_sheet_slicer_set_sheet (GnmSheetSlicer *gss, Sheet *sheet)
 {
 	g_return_if_fail (IS_SHEET (sheet));
-	g_return_if_fail (IS_GNM_SHEET_SLICER (gss));
+	g_return_if_fail (GNM_IS_SHEET_SLICER (gss));
 	g_return_if_fail (NULL == gss->sheet);
 
 	g_object_ref (gss);
@@ -214,7 +214,7 @@ gnm_sheet_slicer_set_sheet (GnmSheetSlicer *gss, Sheet *sheet)
 void
 gnm_sheet_slicer_clear_sheet (GnmSheetSlicer *gss)
 {
-	g_return_if_fail (IS_GNM_SHEET_SLICER (gss));
+	g_return_if_fail (GNM_IS_SHEET_SLICER (gss));
 	g_return_if_fail (NULL != gss->sheet);
 
 	gss->sheet->slicers = g_slist_remove (gss->sheet->slicers, gss);
@@ -225,19 +225,19 @@ gnm_sheet_slicer_clear_sheet (GnmSheetSlicer *gss)
 GnmRange const	*
 gnm_sheet_slicer_get_range (GnmSheetSlicer const *gss)
 {
-	g_return_val_if_fail (IS_GNM_SHEET_SLICER (gss), NULL);
+	g_return_val_if_fail (GNM_IS_SHEET_SLICER (gss), NULL);
 	return &gss->range;
 }
 
 void
 gnm_sheet_slicer_set_range (GnmSheetSlicer *gss, GnmRange const *r)
 {
-	g_return_if_fail (IS_GNM_SHEET_SLICER (gss));
+	g_return_if_fail (GNM_IS_SHEET_SLICER (gss));
 	gss->range = *r;
 }
 
 /**
- * gnm_sheet_slicer_overlaps_range :
+ * gnm_sheet_slicer_overlaps_range:
  * @gss: #GnmSheetSlicer
  * @r: #GnmRange
  *
@@ -246,12 +246,12 @@ gnm_sheet_slicer_set_range (GnmSheetSlicer *gss, GnmRange const *r)
 gboolean
 gnm_sheet_slicer_overlaps_range (GnmSheetSlicer const *gss, GnmRange const *r)
 {
-	g_return_val_if_fail (IS_GNM_SHEET_SLICER (gss), FALSE);
+	g_return_val_if_fail (GNM_IS_SHEET_SLICER (gss), FALSE);
 	return range_overlap (&gss->range, r);
 }
 
 /**
- * gnm_sheet_slicer_field_header_at_pos :
+ * gnm_sheet_slicer_field_header_at_pos:
  * @gss: #GnmSheetSlicer const
  * @pos: #GnmCellPos const
  *
@@ -267,7 +267,7 @@ gnm_sheet_slicer_field_header_at_pos (GnmSheetSlicer const *gss,
 	int res = -1;
 	unsigned int c, r;
 
-	g_return_val_if_fail (IS_GNM_SHEET_SLICER (gss), NULL);
+	g_return_val_if_fail (GNM_IS_SHEET_SLICER (gss), NULL);
 
 	/* 0) TODO page fields */
 	if (pos->col < gss->range.start.col || pos->row < gss->range.start.row)
@@ -371,7 +371,7 @@ gnm_sheet_slicer_regenerate (GnmSheetSlicer *gss)
 	GArray *permutation, *rows;
 	unsigned int i, n;
 
-	g_return_if_fail (IS_GNM_SHEET_SLICER (gss));
+	g_return_if_fail (GNM_IS_SHEET_SLICER (gss));
 	g_return_if_fail (IS_SHEET (gss->sheet));
 	g_return_if_fail (NULL != gss->base.cache);
 
@@ -386,14 +386,14 @@ gnm_sheet_slicer_regenerate (GnmSheetSlicer *gss)
 GnmSheetSlicerLayout
 gnm_sheet_slicer_get_layout (GnmSheetSlicer const *gss)
 {
-	g_return_val_if_fail (IS_GNM_SHEET_SLICER (gss), GSS_Layout_XL_outline);
+	g_return_val_if_fail (GNM_IS_SHEET_SLICER (gss), GSS_LAYOUT_XL_OUTLINE);
 	return gss->layout;
 }
 
 void
 gnm_sheet_slicer_set_layout (GnmSheetSlicer *gss, GnmSheetSlicerLayout l)
 {
-	g_return_if_fail (IS_GNM_SHEET_SLICER (gss));
+	g_return_if_fail (GNM_IS_SHEET_SLICER (gss));
 	gss->layout = l;
 }
 
@@ -403,9 +403,9 @@ gnm_sheet_slicer_layout_get_type (void)
 	static GType etype = 0;
 	if (etype == 0) {
 		static GEnumValue const values[] = {
-			{ GSS_Layout_XL_outline, "GSS_Layout_XL_outline", "xl-outline" },
-			{ GSS_Layout_XL_compact, "GSS_Layout_XL_compact", "xl-compact" },
-			{ GSS_Layout_XL_tabular, "GSS_Layout_XL_tabular", "xl-tabular" },
+			{ GSS_LAYOUT_XL_OUTLINE, "GSS_LAYOUT_XL_OUTLINE", "xl-outline" },
+			{ GSS_LAYOUT_XL_COMPACT, "GSS_LAYOUT_XL_COMPACT", "xl-compact" },
+			{ GSS_LAYOUT_XL_TABULAR, "GSS_LAYOUT_XL_TABULAR", "xl-tabular" },
 			{ 0, NULL, NULL }
 		};
 		etype = g_enum_register_static ("GnmSheetSlicerLayout", values);
