@@ -460,7 +460,7 @@ kill_popup_menu (GtkWidget *widget, G_GNUC_UNUSED gpointer user)
 }
 
 /**
- * gnumeric_popup_menu :
+ * gnumeric_popup_menu:
  * @menu: #GtkMenu
  * @event: #GdkEvent optionally NULL
  *
@@ -701,9 +701,9 @@ gnm_create_popup_menu (GnmPopupMenuElement const *elements,
 }
 
 void
-gnm_init_help_button (GtkWidget *w, char const *link)
+gnm_init_help_button (GtkWidget *w, char const *lnk)
 {
-	go_gtk_help_button_init (w, gnm_sys_data_dir (), "gnumeric", link);
+	go_gtk_help_button_init (w, gnm_sys_data_dir (), "gnumeric", lnk);
 }
 
 char *
@@ -1359,153 +1359,4 @@ gnm_style_context_get_color (GtkStyleContext *context,
 	gtk_style_context_restore (context);
 }
 
-// ---------------------------------------------------------------------------
-// Foreign drawing style code copied from foreigndrawing.c
-
-#if GTK_CHECK_VERSION(3,20,0)
-static void
-append_element (GtkWidgetPath *path,
-                const char    *selector)
-{
-  static const struct {
-    const char    *name;
-    GtkStateFlags  state_flag;
-  } pseudo_classes[] = {
-    { "active",        GTK_STATE_FLAG_ACTIVE },
-    { "hover",         GTK_STATE_FLAG_PRELIGHT },
-    { "selected",      GTK_STATE_FLAG_SELECTED },
-    { "disabled",      GTK_STATE_FLAG_INSENSITIVE },
-    { "indeterminate", GTK_STATE_FLAG_INCONSISTENT },
-    { "focus",         GTK_STATE_FLAG_FOCUSED },
-    { "backdrop",      GTK_STATE_FLAG_BACKDROP },
-    { "dir(ltr)",      GTK_STATE_FLAG_DIR_LTR },
-    { "dir(rtl)",      GTK_STATE_FLAG_DIR_RTL },
-    { "link",          GTK_STATE_FLAG_LINK },
-    { "visited",       GTK_STATE_FLAG_VISITED },
-    { "checked",       GTK_STATE_FLAG_CHECKED },
-    { "drop(active)",  GTK_STATE_FLAG_DROP_ACTIVE }
-  };
-  const char *next;
-  char *name;
-  char type;
-  guint i;
-
-  next = strpbrk (selector, "#.:");
-  if (next == NULL)
-    next = selector + strlen (selector);
-
-  name = g_strndup (selector, next - selector);
-  if (g_ascii_isupper (selector[0]))
-    {
-      GType gtype;
-      gtype = g_type_from_name (name);
-      if (gtype == G_TYPE_INVALID)
-        {
-          g_critical ("Unknown type name `%s'", name);
-          g_free (name);
-          return;
-        }
-      gtk_widget_path_append_type (path, gtype);
-    }
-  else
-    {
-      /* Omit type, we're using name */
-      gtk_widget_path_append_type (path, G_TYPE_NONE);
-      gtk_widget_path_iter_set_object_name (path, -1, name);
-    }
-  g_free (name);
-
-  while (*next != '\0')
-    {
-      type = *next;
-      selector = next + 1;
-      next = strpbrk (selector, "#.:");
-      if (next == NULL)
-        next = selector + strlen (selector);
-      name = g_strndup (selector, next - selector);
-
-      switch (type)
-        {
-        case '#':
-          gtk_widget_path_iter_set_name (path, -1, name);
-          break;
-
-        case '.':
-          gtk_widget_path_iter_add_class (path, -1, name);
-          break;
-
-        case ':':
-          for (i = 0; i < G_N_ELEMENTS (pseudo_classes); i++)
-            {
-              if (g_str_equal (pseudo_classes[i].name, name))
-                {
-                  gtk_widget_path_iter_set_state (path,
-                                                  -1,
-                                                  gtk_widget_path_iter_get_state (path, -1)
-                                                  | pseudo_classes[i].state_flag);
-                  break;
-                }
-            }
-          if (i == G_N_ELEMENTS (pseudo_classes))
-            g_critical ("Unknown pseudo-class :%s", name);
-          break;
-
-        default:
-          g_assert_not_reached ();
-          break;
-        }
-
-      g_free (name);
-    }
-}
-
-static GtkStyleContext *
-create_context_for_path (GtkWidgetPath   *path,
-                         GtkStyleContext *parent)
-{
-  GtkStyleContext *context;
-
-  context = gtk_style_context_new ();
-  gtk_style_context_set_path (context, path);
-  gtk_style_context_set_parent (context, parent);
-  /* Unfortunately, we have to explicitly set the state again here
-   * for it to take effect
-   */
-  gtk_style_context_set_state (context, gtk_widget_path_iter_get_state (path, -1));
-  gtk_widget_path_unref (path);
-
-  return context;
-}
-#endif
-
-/**
- * gnm_style_context_from_selector:
- * @parent: (allow-none): style context for container
- * @selector: a css selector
- *
- * Returns: (transfer full): a new style context.
- */
-GtkStyleContext *
-gnm_style_context_from_selector (GtkStyleContext *parent,
-				 const char      *selector)
-{
-#if GTK_CHECK_VERSION(3,20,0)
-  GtkWidgetPath *path;
-
-  if (parent)
-    path = gtk_widget_path_copy (gtk_style_context_get_path (parent));
-  else
-    path = gtk_widget_path_new ();
-
-  append_element (path, selector);
-
-  return create_context_for_path (path, parent);
-#else
-  (void)parent;
-  (void)selector;
-  g_assert_not_reached ();
-  return NULL;
-#endif
-}
-
 // ----------------------------------------------------------------------------
