@@ -256,7 +256,7 @@ icg_error_error_info (GOCmdContext *cc, GOErrorInfo *error)
 {
 	GnmIOContextGtk *icg = GNM_IO_CONTEXT_GTK (cc);
 	if (icg->show_warnings) {
-		GtkWidget *dialog = gnumeric_go_error_info_dialog_create (error);
+		GtkWidget *dialog = gnm_go_error_info_dialog_create (error);
 		gtk_widget_show_all (GTK_WIDGET (dialog));
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
@@ -268,7 +268,7 @@ icg_error_error_info_list (GOCmdContext *cc, GSList *error)
 {
 	GnmIOContextGtk *icg = GNM_IO_CONTEXT_GTK (cc);
 	if (icg->show_warnings && error != NULL && error->data != NULL) {
-		GtkWidget *dialog = gnumeric_go_error_info_dialog_create
+		GtkWidget *dialog = gnm_go_error_info_dialog_create
 			(error->data);
 		gtk_widget_show_all (GTK_WIDGET (dialog));
 		gtk_dialog_run (GTK_DIALOG (dialog));
@@ -343,10 +343,10 @@ icg_set_property (GObject *obj, guint property_id,
 	GnmIOContextGtk *icg = GNM_IO_CONTEXT_GTK (obj);
 
 	switch (property_id) {
-	case PROP_SHOW_SPLASH :
+	case PROP_SHOW_SPLASH:
 		icg->show_splash = g_value_get_boolean (value);
 		break;
-	case PROP_SHOW_WARNINGS :
+	case PROP_SHOW_WARNINGS:
 		icg->show_warnings = g_value_get_boolean (value);
 		break;
 	default:
