@@ -48,6 +48,7 @@
 #include "sheet-private.h"
 #include "xml-sax.h"
 #include "clipboard.h"
+#include "gui-clipboard.h"
 #include "value.h"
 #include "expr.h"
 #include "expr-deriv.h"
@@ -289,6 +290,9 @@ gnm_init (void)
 		return;
 	inited = TRUE;
 
+	// Might be duplicate call, but that's ok
+	gutils_init ();
+
 	libgoffice_init ();
 	_gnm_register_resource ();
 	if (gdk_screen_get_default ()) {
@@ -318,6 +322,7 @@ gnm_init (void)
 	_gnm_expr_init ();
 	gnm_sheet_cell_init ();
 	clipboard_init ();
+	gui_clipboard_init ();
 	dependent_types_init ();
 	gnm_rendered_value_init ();
 	functions_init ();
@@ -337,23 +342,6 @@ gnm_init (void)
 	                          gnm_app_display_dpi_get (FALSE));
 }
 
-/*
- * TODO : do we really want this here ?
- * seems like a better fit in main-application.c
- */
-int
-gnm_dump_func_defs (char const* filename, int dump_type)
-{
-	int retval;
-	GOCmdContext *cc = gnm_cmd_context_stderr_new ();
-
-	gnm_plugins_init (cc);
-	if ((retval = gnm_cmd_context_stderr_get_status (GNM_CMD_CONTEXT_STDERR (cc))) == 0)
-		function_dump_defs (filename, dump_type);
-
-	return retval;
-}
-
 void
 gnm_shutdown (void)
 {
@@ -377,6 +365,7 @@ gnm_shutdown (void)
 
 	gnm_rendered_value_shutdown ();
 	dependent_types_shutdown ();
+	gui_clipboard_shutdown ();
 	clipboard_shutdown ();
 	gnm_sheet_cell_shutdown ();
 	_gnm_expr_deriv_shutdown ();
