@@ -1,6 +1,5 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * gnm-style.c: Storing a style
+ * mstyle.c: Storing a style
  *
  * Authors:
  *   Michael Meeks <mmeeks@gnu.org>
@@ -12,9 +11,13 @@
 #include "gnumeric.h"
 #include "style.h"
 
-#include "gnm-style-impl.h"
 #include "sheet-style.h"
+#include "style-border.h"
+#include "style-font.h"
+#include "style-color.h"
 #include "style-conditions.h"
+#include "validation.h"
+#include "pattern.h"
 #include "hlink.h"
 #include "input-msg.h"
 #include "application.h"
@@ -44,6 +47,77 @@ static GOMemChunk *gnm_style_pool;
 #define CHUNK_FREE(p,v) g_free ((v))
 #endif
 
+
+struct _GnmStyle {
+	unsigned int	changed;
+	unsigned int	set;
+
+	unsigned int    hash_key;
+	unsigned int    hash_key_xl;
+	unsigned int    ref_count;
+	unsigned int    link_count;
+	Sheet	       *linked_sheet;
+
+	PangoAttrList *pango_attrs;
+	double         pango_attrs_zoom;
+	int            pango_attrs_height;
+
+	GnmFont       *font;
+	PangoContext  *font_context;
+
+/* public */
+	struct _GnmStyleColor {
+		GnmColor *font;
+		GnmColor *back;
+		GnmColor *pattern;
+	} color;
+	GnmBorder	*borders[MSTYLE_BORDER_DIAGONAL - MSTYLE_BORDER_TOP + 1];
+	guint32          pattern;
+
+	/* FIXME: TODO use GOFont */
+	struct _GnmStyleFontDetails {
+		GOString	*name;
+		gboolean	bold;
+		gboolean	italic;
+		GnmUnderline	underline;
+		gboolean	strikethrough;
+		GOFontScript	script;
+		double		size;
+	} font_detail;
+
+	GOFormat const *format;
+	GnmHAlign	 h_align;
+	GnmVAlign	 v_align;
+	int		 indent;
+	int		 rotation;
+	int		 text_dir;
+	gboolean         wrap_text;
+	gboolean         shrink_to_fit;
+	gboolean         contents_locked;
+	gboolean         contents_hidden;
+
+	GnmValidation		*validation;
+	GnmHLink		*hlink;
+	GnmInputMsg		*input_msg;
+	GnmStyleConditions	*conditions;
+	GPtrArray		*cond_styles;
+
+	GPtrArray *deps;
+};
+
+#define elem_changed(style, elem) do { (style)->changed |= (1u << (elem)); } while(0)
+#define elem_set(style, elem)	  do { (style)->set |=  (1u << (elem)); } while(0)
+#define elem_unset(style, elem)	  do { (style)->set &= ~(1u << (elem)); } while(0)
+#define elem_is_set(style, elem)  (((style)->set & (1u << (elem))) != 0)
+
+#define MSTYLE_ANY_BORDER            MSTYLE_BORDER_TOP: \
+				case MSTYLE_BORDER_BOTTOM: \
+				case MSTYLE_BORDER_LEFT: \
+				case MSTYLE_BORDER_RIGHT: \
+				case MSTYLE_BORDER_DIAGONAL: \
+				case MSTYLE_BORDER_REV_DIAGONAL
+
+
 #define UNROLLED_FOR(init_,cond_,step_,code_)			\
 do {								\
 	init_;							\
@@ -509,7 +583,7 @@ elem_clear_contents (GnmStyle *style, GnmStyleElement elem)
 }
 
 /**
- * gnm_style_find_conflicts :
+ * gnm_style_find_conflicts:
  * @accum: accumulator #GnmStyle
  * @overlay: #GnmStyle
  * @conflicts: flags
@@ -543,11 +617,12 @@ gnm_style_find_conflicts (GnmStyle *accum, GnmStyle const *overlay,
 
 #define GNM_INPUT_MSG_EQUAL3(a,b,r) (gnm_input_msg_equal (a,b))
 
-#define RELAX_CHECK(op_,field_,checker_) do {				\
+#define RELAX_CHECK(op_,field_,checker_) do {			\
 	if (diffs & (1u << (op_)) &&				\
 	    elem_is_set (a, (op_)) &&				\
 	    elem_is_set (b, (op_)) &&				\
-	    checker_ (a->field_, b->field_, relax_sheet))	\
+	    ((a->field_ == NULL) != (b->field_ == NULL) ||	\
+	     checker_ (a->field_, b->field_, relax_sheet)))	\
 		diffs &= ~(1u << (op_));			\
 	} while (0)
 
@@ -610,11 +685,9 @@ gnm_style_clear_font (GnmStyle *style)
 }
 
 /**
- * gnm_style_new :
+ * gnm_style_new:
  *
- * Caller is responsible for unrefing the result.
- *
- * Returns a new style with _no_ elements set.
+ * Returns: (transfer full): a new style with _no_ elements set.
  **/
 GnmStyle *
 gnm_style_new (void)
@@ -642,9 +715,7 @@ gnm_style_new (void)
 /**
  * gnm_style_new_default:
  *
- * Caller is responsible for unrefing the result.
- *
- * Return value: a new style initialized to the default state.
+ * Returns: (transfer full): a new style initialized to the default state.
  **/
 GnmStyle *
 gnm_style_new_default (void)
@@ -717,7 +788,7 @@ gnm_style_dup (GnmStyle const *src)
 }
 
 /**
- * gnm_style_new_merged :
+ * gnm_style_new_merged:
  * @base: #GnmStyle
  * @overlay: #GnmStyle
  *
@@ -747,18 +818,26 @@ gnm_style_new_merged (GnmStyle const *base, GnmStyle const *overlay)
 	return new_style;
 }
 
-void
+/**
+ * gnm_style_ref: (skip)
+ * @style: #GnmStyle
+ *
+ * Returns: (transfer full): A new reference to @style.
+ */
+GnmStyle *
 gnm_style_ref (GnmStyle const *style)
 {
-	g_return_if_fail (style != NULL);
-	g_return_if_fail (style->ref_count > 0);
+	g_return_val_if_fail (style != NULL, NULL);
+	g_return_val_if_fail (style->ref_count > 0, NULL);
 
 	((GnmStyle *)style)->ref_count++;
 	d(("ref %p = %d\n", style, style->ref_count));
+
+	return ((GnmStyle *)style);
 }
 
 /**
- * gnm_style_unref :
+ * gnm_style_unref: (skip)
  * @style: #GnmStyle const
  *
  * Unrefs and _potentially frees_ @style.
@@ -925,7 +1004,7 @@ gnm_style_linked_sheet_changed (GnmStyle *style)
 }
 
 /**
- * gnm_style_link_sheet :
+ * gnm_style_link_sheet:
  * @style:
  * @sheet:
  *
@@ -1002,6 +1081,14 @@ gnm_style_unlink (GnmStyle *style)
 	}
 }
 
+// Internal function for sheet-style.c use only
+void
+gnm_style_abandon_link (GnmStyle *style)
+{
+	style->link_count = 0;
+	style->linked_sheet = NULL;
+}
+
 gboolean
 gnm_style_eq (GnmStyle const *a, GnmStyle const *b)
 {
@@ -1168,7 +1255,7 @@ gnm_style_cmp (GnmStyle const *a, GnmStyle const *b)
 
 
 /**
- * gnm_style_equal_header :
+ * gnm_style_equal_header:
  * @a: #GnmStyle
  * @b: #GnmStyle
  * @top: is this a header vertically or horizontally
@@ -1202,7 +1289,7 @@ gnm_style_is_element_set (GnmStyle const *style, GnmStyleElement elem)
 }
 
 /**
- * gnm_style_is_complete :
+ * gnm_style_is_complete:
  * @style: #GnmStyle
  *
  * Returns TRUE if all elements are set.
@@ -1228,7 +1315,7 @@ gnm_style_unset_element (GnmStyle *style, GnmStyleElement elem)
 }
 
 /**
- * gnm_style_merge :
+ * gnm_style_merge:
  * @base: #GnmStyle
  * @overlay: #GnmStyle
  *
@@ -1290,7 +1377,7 @@ gnm_style_set_font_color (GnmStyle *style, GnmColor *col)
 }
 
 /**
- * gnm_style_set_back_color :
+ * gnm_style_set_back_color:
  * @style: #GnmStyle
  * @col: #GnmColor
  *
@@ -1457,6 +1544,12 @@ gnm_style_get_font (GnmStyle const *style, PangoContext *context)
 	return style->font;
 }
 
+/**
+ * gnm_style_set_font_name:
+ * @style: the style to change
+ * @name: the font name as a string
+ *
+ */
 void
 gnm_style_set_font_name (GnmStyle *style, char const *name)
 {
@@ -1473,6 +1566,12 @@ gnm_style_set_font_name (GnmStyle *style, char const *name)
 	gnm_style_clear_pango (style);
 }
 
+/**
+ * gnm_style_get_font_name:
+ * @style: the style to query
+ *
+ * Returns: (transfer none): the currently set font name
+ */
 char const *
 gnm_style_get_font_name (GnmStyle const *style)
 {
@@ -1494,6 +1593,12 @@ gnm_style_set_font_bold (GnmStyle *style, gboolean bold)
 	gnm_style_clear_pango (style);
 }
 
+/**
+ * gnm_style_get_font_bold:
+ * @style: #GnmStyle to query
+ *
+ * Returns: %TRUE if the style has a bold font.
+ */
 gboolean
 gnm_style_get_font_bold (GnmStyle const *style)
 {
@@ -1965,6 +2070,28 @@ gnm_style_get_conditions (GnmStyle const *style)
 	return style->conditions;
 }
 
+/**
+ * gnm_style_get_cond_style:
+ * @style: #GnmStyle
+ * @ix: The index of the condition for which style is desired
+ *
+ * Returns: (transfer none): the resulting style from applying the condition's
+ * style overlay onto @style.
+ **/
+GnmStyle const *
+gnm_style_get_cond_style (GnmStyle const *style, int ix)
+{
+	g_return_val_if_fail (style != NULL, NULL);
+	g_return_val_if_fail (elem_is_set (style, MSTYLE_CONDITIONS), NULL);
+	g_return_val_if_fail (style->cond_styles != NULL, NULL);
+
+	g_return_val_if_fail (ix >= 0 && (unsigned)ix < style->cond_styles->len, NULL);
+
+	return g_ptr_array_index (style->cond_styles, ix);
+}
+
+
+
 static gboolean
 debug_style_deps (void)
 {
@@ -2115,7 +2242,7 @@ add_attr (PangoAttrList *attrs, PangoAttribute *attr)
 }
 
 /**
- * gnm_style_get_pango_attrs :
+ * gnm_style_get_pango_attrs:
  * @style: #GnmStyle
  **/
 PangoAttrList *
@@ -2158,13 +2285,13 @@ gnm_style_get_pango_attrs (GnmStyle const *style,
 
 	/* Handle script. */
 	switch (gnm_style_get_font_script (style)) {
-	default :
-	case GO_FONT_SCRIPT_STANDARD :
+	default:
+	case GO_FONT_SCRIPT_STANDARD:
 		break;
-	case GO_FONT_SCRIPT_SUB :
+	case GO_FONT_SCRIPT_SUB:
 		add_attr (l, go_pango_attr_subscript_new (TRUE));
 		break;
-	case GO_FONT_SCRIPT_SUPER :
+	case GO_FONT_SCRIPT_SUPER:
 		add_attr (l, go_pango_attr_superscript_new (TRUE));
 		break;
 	}
@@ -2246,31 +2373,31 @@ void
 gnm_style_set_from_pango_attribute (GnmStyle *style, PangoAttribute const *attr)
 {
 	switch (attr->klass->type) {
-	case PANGO_ATTR_FAMILY :
+	case PANGO_ATTR_FAMILY:
 		gnm_style_set_font_name (style, ((PangoAttrString *)attr)->value);
 		break;
-	case PANGO_ATTR_SIZE :
+	case PANGO_ATTR_SIZE:
 		gnm_style_set_font_size (style,
 					 ((PangoAttrInt *)attr)->value / (double)PANGO_SCALE);
 		break;
-	case PANGO_ATTR_STYLE :
+	case PANGO_ATTR_STYLE:
 		gnm_style_set_font_italic (style,
 			((PangoAttrInt *)attr)->value == PANGO_STYLE_ITALIC);
 		break;
-	case PANGO_ATTR_WEIGHT :
+	case PANGO_ATTR_WEIGHT:
 		gnm_style_set_font_bold (style,
 			((PangoAttrInt *)attr)->value >= PANGO_WEIGHT_BOLD);
 		break;
-	case PANGO_ATTR_FOREGROUND :
+	case PANGO_ATTR_FOREGROUND:
 		gnm_style_set_font_color (style, gnm_color_new_pango (
 			&((PangoAttrColor *)attr)->color));
 		break;
-	case PANGO_ATTR_UNDERLINE :
+	case PANGO_ATTR_UNDERLINE:
 		gnm_style_set_font_uline
 			(style, gnm_translate_underline_from_pango
 			 (((PangoAttrInt *)attr)->value));
 		break;
-	case PANGO_ATTR_STRIKETHROUGH :
+	case PANGO_ATTR_STRIKETHROUGH:
 		gnm_style_set_font_strike (style,
 			((PangoAttrInt *)attr)->value != 0);
 		break;
@@ -2360,24 +2487,24 @@ gnm_style_dump (GnmStyle const *style)
 		g_printerr (style->font_detail.italic ? "\titalic\n" : "\tnot italic\n");
 	if (elem_is_set (style, MSTYLE_FONT_UNDERLINE))
 		switch (style->font_detail.underline) {
-		default :
-		case UNDERLINE_NONE :
+		default:
+		case UNDERLINE_NONE:
 			g_printerr ("\tno underline\n"); break;
-		case UNDERLINE_SINGLE :
+		case UNDERLINE_SINGLE:
 			g_printerr ("\tsingle underline\n"); break;
-		case UNDERLINE_DOUBLE :
+		case UNDERLINE_DOUBLE:
 			g_printerr ("\tdouble underline\n"); break;
 		}
 	if (elem_is_set (style, MSTYLE_FONT_STRIKETHROUGH))
 		g_printerr (style->font_detail.strikethrough ? "\tstrikethrough\n" : "\tno strikethrough\n");
 	if (elem_is_set (style, MSTYLE_FONT_SCRIPT))
 		switch (style->font_detail.script) {
-		case GO_FONT_SCRIPT_SUB :
+		case GO_FONT_SCRIPT_SUB:
 			g_printerr ("\tsubscript\n"); break;
-		default :
-		case GO_FONT_SCRIPT_STANDARD :
+		default:
+		case GO_FONT_SCRIPT_STANDARD:
 			g_printerr ("\tno super or sub\n"); break;
-		case GO_FONT_SCRIPT_SUPER :
+		case GO_FONT_SCRIPT_SUPER:
 			g_printerr ("\tsuperscript\n"); break;
 		}
 	if (elem_is_set (style, MSTYLE_FONT_SIZE))
@@ -2416,6 +2543,9 @@ gnm_style_dump (GnmStyle const *style)
 
 /* ------------------------------------------------------------------------- */
 
+/**
+ * gnm_style_init: (skip)
+ */
 void
 gnm_style_init (void)
 {
@@ -2437,6 +2567,9 @@ cb_gnm_style_pool_leak (gpointer data, G_GNUC_UNUSED gpointer user)
 }
 #endif
 
+/**
+ * gnm_style_shutdown: (skip)
+ */
 void
 gnm_style_shutdown (void)
 {
