@@ -76,8 +76,7 @@ gnm_search_normalize_result (const char *txt)
 static gboolean
 check_number (GnmSearchReplace *sr)
 {
-	GODateConventions const *date_conv =
-		workbook_date_conv (sr->sheet->workbook);
+	GODateConventions const *date_conv = sheet_date_conv (sr->sheet);
 	GOSearchReplace *gosr = (GOSearchReplace *)sr;
 	GnmValue *v = format_match_number (gosr->search_text, NULL, date_conv);
 
@@ -240,10 +239,8 @@ gnm_search_collect_cells (GnmSearchReplace *sr)
 	}
 
 	/* Sort our cells.  */
-	qsort (&g_ptr_array_index (cells, 0),
-	       cells->len,
-	       sizeof (gpointer),
-	       sr->by_row ? cb_order_sheet_row_col : cb_order_sheet_col_row);
+	g_ptr_array_sort (cells,
+			  sr->by_row ? cb_order_sheet_row_col : cb_order_sheet_col_row);
 
 	return cells;
 }
