@@ -24,7 +24,7 @@ typedef struct {
 					 GnmRange const * r);
 	void (*ant)			(SheetControl *sc);
 	void (*unant)			(SheetControl *sc);
-	void (*scrollbar_config)	(SheetControl const *sc);
+	void (*scrollbar_config)	(SheetControl *sc);
 	void (*mode_edit)		(SheetControl *sc);
 	void (*set_top_left)		(SheetControl *sc, int col, int row);
 	void (*recompute_visible_region)(SheetControl *sc,
@@ -39,7 +39,7 @@ typedef struct {
 					 GnmInputMsg *im, GnmCellPos *pos);
 } SheetControlClass;
 
-#define SHEET_CONTROL_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), SHEET_CONTROL_TYPE, SheetControlClass))
+#define SHEET_CONTROL_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), GNM_SHEET_CONTROL_TYPE, SheetControlClass))
 
 G_END_DECLS
 
