@@ -52,7 +52,7 @@ range_row_cmp (GnmRange const *a, GnmRange const *b)
  * @r: The region to merge
  * @clear: should the non-corner content of the region be cleared and the
  *          style from the corner applied.
- * @cc: the calling context
+ * @cc: (nullable): the calling context
  *
  * Add a range to the list of merge targets.  Checks for array spliting returns
  * %TRUE if there was an error.  Queues a respan.  Only queus a redraw if @clear
@@ -65,7 +65,6 @@ gnm_sheet_merge_add (Sheet *sheet, GnmRange const *r, gboolean clear,
 	GSList *test;
 	GnmRange  *r_copy;
 	GnmCell   *cell;
-	GnmStyle *style;
 	GnmComment *comment;
 	GnmRange r2;
 
@@ -92,6 +91,7 @@ gnm_sheet_merge_add (Sheet *sheet, GnmRange const *r, gboolean clear,
 
 	if (clear) {
 		int i;
+		GnmStyle *style;
 
 		sheet_redraw_range (sheet, &r2);
 
@@ -136,7 +136,7 @@ gnm_sheet_merge_add (Sheet *sheet, GnmRange const *r, gboolean clear,
 	SHEET_FOREACH_VIEW (sheet, sv, {
 		sv->reposition_selection = TRUE;
 		if (range_contains (&r2, sv->edit_pos.col, sv->edit_pos.row))
-			sv_set_edit_pos (sv, &r2.start);
+			gnm_sheet_view_set_edit_pos (sv, &r2.start);
 	});
 
 	comment = sheet_get_comment (sheet, &r2.start);
@@ -159,7 +159,6 @@ gnm_sheet_merge_add (Sheet *sheet, GnmRange const *r, gboolean clear,
  * gnm_sheet_merge_remove:
  * @sheet: the sheet which will contain the region
  * @r: The region
- * @cc: the calling context
  *
  * Remove a merged range.
  * Queues a redraw.
@@ -167,7 +166,7 @@ gnm_sheet_merge_add (Sheet *sheet, GnmRange const *r, gboolean clear,
  * Returns: %TRUE if there was an error.
  **/
 gboolean
-gnm_sheet_merge_remove (Sheet *sheet, GnmRange const *r, GOCmdContext *cc)
+gnm_sheet_merge_remove (Sheet *sheet, GnmRange const *r)
 {
 	GnmRange   *r_copy;
 	GnmCell    *cell;
@@ -205,7 +204,6 @@ gnm_sheet_merge_remove (Sheet *sheet, GnmRange const *r, GOCmdContext *cc)
  * Returns: (element-type GnmRange) (transfer container): a list of the merged
  * regions that overlap the target region.
  * The list is ordered from top to bottom and RIGHT TO LEFT (by start coord).
- * Caller is responsible for freeing the list, but not the content.
  */
 GSList *
 gnm_sheet_merge_get_overlap (Sheet const *sheet, GnmRange const *range)
@@ -227,9 +225,11 @@ gnm_sheet_merge_get_overlap (Sheet const *sheet, GnmRange const *range)
 
 /**
  * gnm_sheet_merge_contains_pos:
+ * @sheet: #Sheet to query
+ * @pos: Position to look for a merged range.
  *
- * If the GnmCellPos is contained in a merged region return the range.
- * The GnmRange should NOT be freed.
+ * Returns: (transfer none) (nullable): the merged range covering @pos, or
+ * %NULL if @pos is not within a merged region.
  */
 GnmRange const *
 gnm_sheet_merge_contains_pos (Sheet const *sheet, GnmCellPos const *pos)
@@ -286,11 +286,11 @@ gnm_sheet_merge_get_adjacent (Sheet const *sheet, GnmCellPos const *pos,
 
 /**
  * gnm_sheet_merge_is_corner:
- * @sheet:
+ * @sheet: #Sheet to query
  * @pos: cellpos if top left corner
  *
- * Returns a GnmRange pointer if the @pos is the topleft of a merged region.
- * The pointer should NOT be freed by the caller.
+ * Returns: (transfer none): a merged #GnmRange covering @pos if is the
+ * top-left corner of a merged region.
  */
 GnmRange const *
 gnm_sheet_merge_is_corner (Sheet const *sheet, GnmCellPos const *pos)
@@ -317,7 +317,7 @@ cb_restore_merge (Sheet *sheet, GSList *restore)
 		// the old state, so we'll have to remove the merge and
 		// create a new.
 		if (r2)
-			gnm_sheet_merge_remove (sheet, r2, NULL);
+			gnm_sheet_merge_remove (sheet, r2);
 
 		gnm_sheet_merge_add (sheet, r, FALSE, NULL);
 	}
@@ -332,6 +332,7 @@ cb_restore_list_free (GSList *restore)
 /**
  * gnm_sheet_merge_relocate:
  * @ri: Descriptor of what is moving.
+ * @pundo: (out) (optional) (transfer full): Undo information.
  *
  * Shifts merged regions that need to move.
  */
@@ -356,7 +357,7 @@ gnm_sheet_merge_relocate (GnmExprRelocateInfo const *ri, GOUndo **pundo)
 		for (ptr = copy; ptr != NULL ; ptr = ptr->next) {
 			GnmRange const *r = ptr->data;
 			if (range_contains (&dest, r->start.col, r->start.row))
-				gnm_sheet_merge_remove (ri->target_sheet, r, NULL);
+				gnm_sheet_merge_remove (ri->target_sheet, r);
 		}
 		g_slist_free (copy);
 	}
@@ -374,7 +375,7 @@ gnm_sheet_merge_relocate (GnmExprRelocateInfo const *ri, GOUndo **pundo)
 					 ri->col_offset, ri->row_offset);
 			range_ensure_sanity (&r2, ri->target_sheet);
 
-			gnm_sheet_merge_remove (ri->origin_sheet, r, NULL);
+			gnm_sheet_merge_remove (ri->origin_sheet, r);
 			if (range_is_singleton (&r2))
 				needs_restore = TRUE;
 			else if (r2.start.col <= r2.end.col &&
@@ -388,12 +389,12 @@ gnm_sheet_merge_relocate (GnmExprRelocateInfo const *ri, GOUndo **pundo)
 			r2.end.col += ri->col_offset;
 			r2.end.row += ri->row_offset;
 			range_ensure_sanity (&r2, ri->target_sheet);
-			gnm_sheet_merge_remove (ri->origin_sheet, r, NULL);
+			gnm_sheet_merge_remove (ri->origin_sheet, r);
 			needs_restore = TRUE;
 			needs_reapply = !range_is_singleton (&r2);
 		} else if (!change_sheets &&
 			   range_contains (&dest, r->start.col, r->start.row))
-			gnm_sheet_merge_remove (ri->origin_sheet, r, NULL);
+			gnm_sheet_merge_remove (ri->origin_sheet, r);
 
 		if (needs_reapply)
 			reapply = g_slist_prepend (reapply,
@@ -423,12 +424,14 @@ gnm_sheet_merge_relocate (GnmExprRelocateInfo const *ri, GOUndo **pundo)
 }
 
 /**
- * gnm_sheet_merge_find_container:
+ * gnm_sheet_merge_find_bounding_box:
  * @sheet: sheet
- * @r: the range to test
+ * @r: the range to exten
+ *
+ * Extends @r such that no merged range is split by its boundary.
  */
 void
-gnm_sheet_merge_find_container (Sheet const *sheet, GnmRange *target)
+gnm_sheet_merge_find_bounding_box (Sheet const *sheet, GnmRange *target)
 {
 	gboolean changed;
 	GSList *merged, *ptr;
