@@ -299,7 +299,7 @@ enumerate_functions (gboolean filter)
 }
 
 /**
- * function_dump_defs :
+ * function_dump_defs:
  * @filename:
  * @dump_type:
  *
@@ -307,7 +307,7 @@ enumerate_functions (gboolean filter)
  * in various ways.  @dump_type will change/extend as needed
  * Right now
  * 0 : www.gnumeric.org's function.shtml page
- * 1 :
+ * 1:
  * 2 : (obsolete)
  * 3 : dump function usage count
  * 4 : external refs
@@ -533,7 +533,7 @@ function_dump_defs (char const *filename, int dump_type)
 				}
 			}
 
-			function_def_count_args (fd, &min, &max);
+			gnm_func_count_args (fd, &min, &max);
 			if (max == G_MAXINT)
 				fprintf (output_file,
 					 "@SYNTAX=%s," UNICODE_ELLIPSIS ")\n",
@@ -961,7 +961,7 @@ check_argument_refs (const char *text, GnmFunc const *fd)
 		argname = g_strndup (at + 2, text - at - 2);
 
 		for (i = 0; TRUE; i++) {
-			char *thisarg = function_def_get_arg_name (fd, i);
+			char *thisarg = gnm_func_get_arg_name (fd, i);
 			gboolean found;
 			if (!thisarg) {
 				g_free (argname);
