@@ -18,8 +18,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
@@ -229,7 +228,7 @@ gnm_undo_filter_set_condition_undo (GOUndo *u, G_GNUC_UNUSED gpointer data)
 				  gnm_filter_condition_dup (ua->cond), TRUE);
 	sheet_update (ua->filter->sheet);
 
-	colrow_foreach (&ua->filter->sheet->rows,
+	sheet_colrow_foreach (ua->filter->sheet, FALSE,
 			ua->filter->r.start.row + 1,
 			ua->filter->r.end.row,
 			(ColRowHandler) cb_filter_set_condition_undo,
