@@ -18,8 +18,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
@@ -231,7 +230,7 @@ gnm_validation_op_get_type (void)
 /***************************************************************************/
 
 /**
- * gnm_validation_new :
+ * gnm_validation_new:
  * @title: will be copied.
  * @msg: will be copied.
  * @texpr0: absorb the reference to the expression (optionally %NULL).
@@ -361,11 +360,12 @@ gnm_validation_equal (GnmValidation const *a, GnmValidation const *b,
 }
 
 
-void
+GnmValidation *
 gnm_validation_ref (GnmValidation const *v)
 {
-	g_return_if_fail (v != NULL);
+	g_return_val_if_fail (v != NULL, NULL);
 	((GnmValidation *)v)->ref_count++;
+	return ((GnmValidation *)v);
 }
 
 void
@@ -434,7 +434,7 @@ gnm_validation_set_sheet (GnmValidation *v, Sheet *sheet)
 
 
 /**
- * gnm_validation_set_expr :
+ * gnm_validation_set_expr:
  * @v: #GnmValidation
  * @texpr: #GnmExprTop
  * @indx: 0 or 1
