@@ -85,7 +85,8 @@ enum {
 	PROP_DO_AUTO_COMPLETION,
 	PROP_PROTECTED,
 	PROP_PREFERRED_WIDTH,
-	PROP_PREFERRED_HEIGHT
+	PROP_PREFERRED_HEIGHT,
+	PROP_WORKBOOK
 };
 
 /* WorkbookView signals */
@@ -120,7 +121,7 @@ wb_view_get_doc (WorkbookView const *wbv)
 }
 
 /**
- * wb_view_get_index_in_wb :
+ * wb_view_get_index_in_wb:
  * @wbv: #WorkbookView
  *
  * Returns 0 based index of wbv within workbook, or -1 if there is no workbook.
@@ -196,7 +197,7 @@ wb_view_sheet_add (WorkbookView *wbv, Sheet *new_sheet)
 
 	g_return_if_fail (GNM_IS_WORKBOOK_VIEW (wbv));
 
-	new_view = sheet_view_new (new_sheet, wbv);
+	new_view = gnm_sheet_view_new (new_sheet, wbv);
 
 	WORKBOOK_VIEW_FOREACH_CONTROL (wbv, control,
 		wb_control_sheet_add (control, new_view););
@@ -367,9 +368,20 @@ wb_view_menus_update (WorkbookView *wbv)
 	}
 }
 
+/**
+ * wb_view_selection_desc:
+ * @wbv: The view
+ * @use_pos: 
+ * @wbc: (allow-none): A #WorkbookControl
+ *
+ * Load the edit line with the value of the cell in sheet's edit_pos.
+ *
+ * Calculate what to display on the edit line then display it either in the
+ * control @wbc, or if that is %NULL, in all controls.
+ */
 void
 wb_view_selection_desc (WorkbookView *wbv, gboolean use_pos,
-			WorkbookControl *optional_wbc)
+			WorkbookControl *wbc)
 {
 	SheetView *sv;
 
@@ -381,7 +393,7 @@ wb_view_selection_desc (WorkbookView *wbv, gboolean use_pos,
 		char const *sel_descr = buffer;
 		GnmRange const *r, *m;
 
-		g_return_if_fail (GNM_IS_SV (sv));
+		g_return_if_fail (GNM_IS_SHEET_VIEW (sv));
 		g_return_if_fail (sv->selections);
 
 		r = selection_first_range (sv, NULL, NULL);
@@ -411,26 +423,26 @@ wb_view_selection_desc (WorkbookView *wbv, gboolean use_pos,
 					  rows, cols);
 		}
 
-		if (optional_wbc == NULL) {
+		if (wbc == NULL) {
 			WORKBOOK_VIEW_FOREACH_CONTROL (wbv, wbc,
 				wb_control_selection_descr_set (wbc, sel_descr););
 		} else
-			wb_control_selection_descr_set (optional_wbc, sel_descr);
+			wb_control_selection_descr_set (wbc, sel_descr);
 	}
 }
 
 /**
  * wb_view_edit_line_set:
  * @wbv: The view
- * @optional_wbc: An Optional control
+ * @wbc: (allow-none): A #WorkbookControl
  *
  * Load the edit line with the value of the cell in @sheet's edit_pos.
  *
  * Calculate what to display on the edit line then display it either in the
- * control @wbc,  or if that is NULL, in all controls.
+ * control @wbc, or if that is %NULL, in all controls.
  */
 void
-wb_view_edit_line_set (WorkbookView *wbv, WorkbookControl *optional_wbc)
+wb_view_edit_line_set (WorkbookView *wbv, WorkbookControl *wbc)
 {
 	SheetView *sv;
 
@@ -444,7 +456,7 @@ wb_view_edit_line_set (WorkbookView *wbv, WorkbookControl *optional_wbc)
 			sv->edit_pos.col, sv->edit_pos.row);
 
 		if (NULL != cell) {
-			text = gnm_cell_get_text_for_editing (cell, sheet, NULL, NULL);
+			text = gnm_cell_get_text_for_editing (cell, NULL, NULL);
 
 			if (gnm_cell_has_expr (cell)) {
 				GnmExprTop const *texpr = cell->base.texpr;
@@ -485,11 +497,11 @@ wb_view_edit_line_set (WorkbookView *wbv, WorkbookControl *optional_wbc)
 		} else
 			text = g_strdup ("");
 
-		if (optional_wbc == NULL) {
+		if (wbc == NULL) {
 			WORKBOOK_VIEW_FOREACH_CONTROL (wbv, control,
 				wb_control_edit_line_set (control, text););
 		} else
-			wb_control_edit_line_set (optional_wbc, text);
+			wb_control_edit_line_set (wbc, text);
 
 		g_free (text);
 	}
@@ -697,7 +709,7 @@ wb_view_set_property (GObject *object, guint property_id,
 
 	switch (property_id) {
 	case PROP_AUTO_EXPR_FUNC:
-		wb_view_auto_expr_func (wbv, g_value_get_pointer (value));
+		wb_view_auto_expr_func (wbv, g_value_get_boxed (value));
 		break;
 	case PROP_AUTO_EXPR_DESCR:
 		wb_view_auto_expr_descr (wbv, g_value_get_string (value));
@@ -709,7 +721,7 @@ wb_view_set_property (GObject *object, guint property_id,
 		wb_view_auto_expr_value (wbv, g_value_get_boxed (value));
 		break;
 	case PROP_AUTO_EXPR_EVAL_POS:
-		wb_view_auto_expr_eval_pos (wbv, g_value_get_pointer (value));
+		wb_view_auto_expr_eval_pos (wbv, g_value_get_boxed (value));
 		break;
 	case PROP_SHOW_HORIZONTAL_SCROLLBAR:
 		wbv->show_horizontal_scrollbar = !!g_value_get_boolean (value);
@@ -742,6 +754,9 @@ wb_view_set_property (GObject *object, guint property_id,
 	case PROP_PREFERRED_HEIGHT:
 		wbv->preferred_height = g_value_get_int (value);
 		break;
+	case PROP_WORKBOOK:
+		wbv->wb = g_value_dup_object (value);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -756,7 +771,7 @@ wb_view_get_property (GObject *object, guint property_id,
 
 	switch (property_id) {
 	case PROP_AUTO_EXPR_FUNC:
-		g_value_set_pointer (value, wbv->auto_expr.func);
+		g_value_set_boxed (value, wbv->auto_expr.func);
 		break;
 	case PROP_AUTO_EXPR_DESCR:
 		g_value_set_string (value, wbv->auto_expr.descr);
@@ -794,6 +809,9 @@ wb_view_get_property (GObject *object, guint property_id,
 	case PROP_PREFERRED_HEIGHT:
 		g_value_set_int (value, wbv->preferred_height);
 		break;
+	case PROP_WORKBOOK:
+		g_value_set_object (value, wbv->wb);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -812,6 +830,35 @@ wb_view_detach_from_workbook (WorkbookView *wbv)
 	}
 }
 
+static GObject *
+wb_view_constructor (GType type,
+		     guint n_construct_properties,
+		     GObjectConstructParam *construct_params)
+{
+	GObject *obj;
+	WorkbookView *wbv;
+	int i;
+
+	obj = parent_class->constructor
+		(type, n_construct_properties, construct_params);
+	wbv = GNM_WORKBOOK_VIEW (obj);
+
+	if (wbv->wb == NULL)
+		wbv->wb = workbook_new ();
+
+	workbook_attach_view (wbv);
+
+	for (i = 0 ; i < workbook_sheet_count (wbv->wb); i++)
+		wb_view_sheet_add (wbv, workbook_sheet_by_index (wbv->wb, i));
+
+	if (wbv->auto_expr.func == NULL) {
+		wb_view_auto_expr_func (wbv, gnm_func_lookup ("sum", NULL));
+		wb_view_auto_expr_descr (wbv, _("Sum"));
+	}
+
+	return obj;
+}
+
 static void
 wb_view_dispose (GObject *object)
 {
@@ -854,6 +901,7 @@ workbook_view_class_init (GObjectClass *gobject_class)
 {
 	parent_class = g_type_class_peek_parent (gobject_class);
 
+	gobject_class->constructor = wb_view_constructor;
 	gobject_class->set_property = wb_view_set_property;
 	gobject_class->get_property = wb_view_get_property;
 	gobject_class->dispose = wb_view_dispose;
@@ -862,11 +910,12 @@ workbook_view_class_init (GObjectClass *gobject_class)
         g_object_class_install_property
 		(gobject_class,
 		 PROP_AUTO_EXPR_FUNC,
-		 g_param_spec_pointer ("auto-expr-func",
-				       P_("Auto-expression function"),
-				       P_("The automatically computed sheet function."),
-				       GSF_PARAM_STATIC |
-				       G_PARAM_READWRITE));
+		 g_param_spec_boxed ("auto-expr-func",
+				     P_("Auto-expression function"),
+				     P_("The automatically computed sheet function."),
+				     gnm_func_get_type (),
+				     GSF_PARAM_STATIC |
+				     G_PARAM_READWRITE));
         g_object_class_install_property
 		(gobject_class,
 		 PROP_AUTO_EXPR_DESCR,
@@ -897,11 +946,12 @@ workbook_view_class_init (GObjectClass *gobject_class)
         g_object_class_install_property
 		(gobject_class,
 		 PROP_AUTO_EXPR_EVAL_POS,
-		 g_param_spec_pointer ("auto-expr-eval-pos",
-				       P_("Auto-expression position"),
-				       P_("The cell position to track."),
-				       GSF_PARAM_STATIC |
-				       G_PARAM_WRITABLE));
+		 g_param_spec_boxed ("auto-expr-eval-pos",
+				     P_("Auto-expression position"),
+				     P_("The cell position to track."),
+				     gnm_eval_pos_get_type (),
+				     GSF_PARAM_STATIC |
+				     G_PARAM_WRITABLE));
         g_object_class_install_property
 		(gobject_class,
 		 PROP_SHOW_HORIZONTAL_SCROLLBAR,
@@ -983,61 +1033,58 @@ workbook_view_class_init (GObjectClass *gobject_class)
 				   1, G_MAXINT, 768,
 				   GSF_PARAM_STATIC |
 				   G_PARAM_READWRITE));
+        g_object_class_install_property
+		(gobject_class,
+		 PROP_WORKBOOK,
+		 g_param_spec_object ("workbook",
+				      P_("Workbook"),
+				      P_("Workbook"),
+				      GNM_WORKBOOK_TYPE,
+				      GSF_PARAM_STATIC |
+				      G_PARAM_CONSTRUCT_ONLY |
+				      G_PARAM_READWRITE));
 
 	parent_class = g_type_class_peek_parent (gobject_class);
 }
 
-GSF_CLASS (WorkbookView, workbook_view,
-	   workbook_view_class_init, NULL, GO_TYPE_VIEW)
+static void
+workbook_view_init (WorkbookView *wbv)
+{
+	wbv->show_horizontal_scrollbar = TRUE;
+	wbv->show_vertical_scrollbar = TRUE;
+	wbv->show_notebook_tabs = TRUE;
+	wbv->show_function_cell_markers =
+		gnm_conf_get_core_gui_cells_function_markers ();
+	wbv->show_extension_markers =
+		gnm_conf_get_core_gui_cells_extension_markers ();
+	wbv->do_auto_completion =
+		gnm_conf_get_core_gui_editing_autocomplete ();
+	wbv->is_protected = FALSE;
 
+	dependent_managed_init (&wbv->auto_expr.dep, NULL);
+}
+
+GSF_CLASS (WorkbookView, workbook_view,
+	   workbook_view_class_init, workbook_view_init, GO_TYPE_VIEW)
+
+/**
+ * workbook_view_new:
+ * @wb: (allow-none) (transfer full): #Workbook
+ *
+ * Returns: A new #WorkbookView for @wb (or a fresh one if that is %NULL).
+ **/
 WorkbookView *
 workbook_view_new (Workbook *wb)
 {
-	WorkbookView *wbv;
-	int i;
-
-	if (wb == NULL)
-		wb = workbook_new ();
-
-	g_return_val_if_fail (wb != NULL, NULL);
-
-	wbv = g_object_new
-		(GNM_WORKBOOK_VIEW_TYPE,
-		 "show-horizontal-scrollbar", TRUE,
-		 "show-vertical-scrollbar", TRUE,
-		 "show-notebook-tabs", TRUE,
-		 "show-function-cell-markers", gnm_conf_get_core_gui_cells_function_markers (),
-		 "show-extension-markers", gnm_conf_get_core_gui_cells_extension_markers (),
-		 "do-auto-completion", gnm_conf_get_core_gui_editing_autocomplete (),
-		 "protected", FALSE,
-		 "auto-expr-value", NULL,
-		 "auto-expr-max-precision", FALSE,
-		 NULL);
-
-	wbv->wb = wb;
-	workbook_attach_view (wbv);
-
-	wbv->current_style      = NULL;
-	wbv->in_cell_combo      = NULL;
-
-	wbv->current_sheet      = NULL;
-	wbv->current_sheet_view = NULL;
-
-	dependent_managed_init (&wbv->auto_expr.dep, NULL);
-
-	for (i = 0 ; i < workbook_sheet_count (wb); i++)
-		wb_view_sheet_add (wbv, workbook_sheet_by_index (wb, i));
-
-	g_object_set (G_OBJECT (wbv),
-		      "auto-expr-func", gnm_func_lookup ("sum", NULL),
-		      "auto-expr-descr", _("Sum"),
-		      NULL);
+	WorkbookView *wbv =
+		g_object_new (GNM_WORKBOOK_VIEW_TYPE, "workbook", wb, NULL);
+	if (wb) g_object_unref (wb);
 
 	return wbv;
 }
 
 /**
- * wbv_save_to_output:
+ * workbook_view_save_to_output:
  * @wbv: #WorkbookView
  * @fs: #GOFileSaver
  * @output: #GsfOutput
@@ -1046,8 +1093,8 @@ workbook_view_new (Workbook *wb)
  * NOTE : Temporary api until we get the new output framework.
  **/
 void
-wbv_save_to_output (WorkbookView *wbv, GOFileSaver const *fs,
-		    GsfOutput *output, GOIOContext *io_context)
+workbook_view_save_to_output (WorkbookView *wbv, GOFileSaver const *fs,
+			      GsfOutput *output, GOIOContext *io_context)
 {
 	GError const *err;
 	char const   *msg;
@@ -1071,9 +1118,17 @@ wbv_save_to_output (WorkbookView *wbv, GOFileSaver const *fs,
 		go_cmd_context_error_export (GO_CMD_CONTEXT (io_context), msg);
 }
 
+/**
+ * workbook_view_save_to_uri:
+ * @wbv: #WorkbookView
+ * @fs: #GOFileSaver
+ * @uri: destination URI
+ * @io_context: #GOIOContext
+ *
+ **/
 void
-wb_view_save_to_uri (WorkbookView *wbv, GOFileSaver const *fs,
-		     char const *uri, GOIOContext *io_context)
+workbook_view_save_to_uri (WorkbookView *wbv, GOFileSaver const *fs,
+			   char const *uri, GOIOContext *io_context)
 {
 	char   *msg = NULL;
 	GError *err = NULL;
@@ -1090,27 +1145,52 @@ wb_view_save_to_uri (WorkbookView *wbv, GOFileSaver const *fs,
 		go_cmd_context_error_export (GO_CMD_CONTEXT (io_context), msg);
 		g_free (msg);
 	} else {
-		wbv_save_to_output (wbv, fs, output, io_context);
+		workbook_view_save_to_output (wbv, fs, output, io_context);
 		g_object_unref (output);
 	}
 }
 
+static GDateTime *
+get_uri_modtime (GsfInput *input, const char *uri)
+{
+	GDateTime *modtime = NULL;
+
+	if (input) {
+		modtime = gsf_input_get_modtime (input);
+		if (modtime)
+			g_date_time_ref (modtime);
+	}
+
+	if (!modtime && uri)
+		modtime = go_file_get_modtime (uri);
+
+	if (gnm_debug_flag ("modtime")) {
+		char *s = modtime
+			? g_date_time_format (modtime, "%F %T")
+			: g_strdup ("?");
+		g_printerr ("Modtime of %s is %s\n", uri, s);
+		g_free (s);
+	}
+
+	return modtime;
+}
+
 /**
- * wb_view_save_as:
+ * workbook_view_save_as:
  * @wbv: Workbook View
  * @fs: GOFileSaver object
  * @uri: URI to save as.
- * @cc:
+ * @cc: The #GOCmdContext that invoked the operation
  *
  * Saves @wbv and workbook it's attached to into @uri file using
  * @fs file saver.  If the format sufficiently advanced make it the saver
  * and update the uri.
  *
- * Return value: TRUE if file was successfully saved and FALSE otherwise.
+ * Return value: %TRUE if file was successfully saved and %FALSE otherwise.
  */
 gboolean
-wb_view_save_as (WorkbookView *wbv, GOFileSaver *fs, char const *uri,
-		 GOCmdContext *cc)
+workbook_view_save_as (WorkbookView *wbv, GOFileSaver *fs, char const *uri,
+		       GOCmdContext *cc)
 {
 	GOIOContext *io_context;
 	Workbook  *wb;
@@ -1126,21 +1206,29 @@ wb_view_save_as (WorkbookView *wbv, GOFileSaver *fs, char const *uri,
 	io_context = go_io_context_new (cc);
 
 	go_cmd_context_set_sensitive (cc, FALSE);
-	wb_view_save_to_uri (wbv, fs, uri, io_context);
+	workbook_view_save_to_uri (wbv, fs, uri, io_context);
 	go_cmd_context_set_sensitive (cc, TRUE);
 
 	has_error   = go_io_error_occurred (io_context);
 	has_warning = go_io_warning_occurred (io_context);
 	if (!has_error) {
-		if (workbook_set_saveinfo
-		    (wb, go_file_saver_get_format_level (fs), fs)) {
+		GOFileFormatLevel fl = go_file_saver_get_format_level (fs);
+		if (workbook_set_saveinfo (wb, fl, fs)) {
 			if (go_doc_set_uri (GO_DOC (wb), uri)) {
+				GDateTime *modtime;
+
 				go_doc_set_dirty (GO_DOC (wb), FALSE);
 				/* See 634792.  */
 				go_doc_set_pristine (GO_DOC (wb), FALSE);
+
+				modtime = get_uri_modtime (NULL, uri);
+				go_doc_set_modtime (GO_DOC (wb), modtime);
+				if (gnm_debug_flag ("modtime"))
+					g_printerr ("Modtime set\n");
+				g_date_time_unref (modtime);
 			}
 		} else
-			workbook_set_last_export_uri (wb, g_strdup (uri));
+			workbook_set_last_export_uri (wb, uri);
 	}
 	if (has_error || has_warning)
 		go_io_error_display (io_context);
@@ -1151,29 +1239,31 @@ wb_view_save_as (WorkbookView *wbv, GOFileSaver *fs, char const *uri,
 }
 
 /**
- * wb_view_save:
+ * workbook_view_save:
  * @wbv: The view to save.
- * @cc: The context that invoked the operation
+ * @cc: The #GOCmdContext that invoked the operation
  *
  * Saves @wbv and workbook it's attached to into file assigned to the
  * workbook using workbook's file saver. If the workbook has no file
  * saver assigned to it, default file saver is used instead.
  *
- * Return value: TRUE if file was successfully saved and FALSE otherwise.
+ * Return value: %TRUE if file was successfully saved and %FALSE otherwise.
  */
 gboolean
-wb_view_save (WorkbookView *wbv, GOCmdContext *context)
+workbook_view_save (WorkbookView *wbv, GOCmdContext *context)
 {
 	GOIOContext	*io_context;
 	Workbook	*wb;
 	GOFileSaver	*fs;
 	gboolean has_error, has_warning;
+	char const *uri;
 
 	g_return_val_if_fail (GNM_IS_WORKBOOK_VIEW (wbv), FALSE);
 	g_return_val_if_fail (GO_IS_CMD_CONTEXT (context), FALSE);
 
 	wb = wb_view_get_workbook (wbv);
 	g_object_ref (wb);
+	uri = go_doc_get_uri (GO_DOC (wb));
 
 	fs = workbook_get_file_saver (wb);
 	if (fs == NULL)
@@ -1185,13 +1275,19 @@ wb_view_save (WorkbookView *wbv, GOCmdContext *context)
 			_("Default file saver is not available."));
 	else {
 		char const *uri = go_doc_get_uri (GO_DOC (wb));
-		wb_view_save_to_uri (wbv, fs, uri, io_context);
+		workbook_view_save_to_uri (wbv, fs, uri, io_context);
 	}
 
 	has_error   = go_io_error_occurred (io_context);
 	has_warning = go_io_warning_occurred (io_context);
-	if (!has_error)
+	if (!has_error) {
+		GDateTime *modtime = get_uri_modtime (NULL, uri);
+		go_doc_set_modtime (GO_DOC (wb), modtime);
+		if (gnm_debug_flag ("modtime"))
+			g_printerr ("Modtime set\n");
+		g_date_time_unref (modtime);
 		go_doc_set_dirty (GO_DOC (wb), FALSE);
+	}
 	if (has_error || has_warning)
 		go_io_error_display (io_context);
 
@@ -1204,41 +1300,42 @@ wb_view_save (WorkbookView *wbv, GOCmdContext *context)
 /**
  * workbook_view_new_from_input:
  * @input: #GsfInput to read data from.
- * @optional_format: Optional GOFileOpener
- * @io_context: Optional context to display errors.
- * @optional_encoding: Optional encoding for GOFileOpener that understand it
+ * @uri: (allow-none): URI
+ * @file_opener: (allow-none): #GOFileOpener
+ * @io_context: (allow-none): Context to display errors.
+ * @encoding: (allow-none): Encoding for @file_opener that understand it
  *
- * Reads @uri file using given file opener @optional_fmt, or probes for a valid
- * possibility if @optional_fmt is NULL.  Reports problems to @io_context.
+ * Reads @uri file using given file opener @file_opener, or probes for a valid
+ * possibility if @file_opener is %NULL.  Reports problems to @io_context.
  *
- * Return value: (transfer full): the newly allocated WorkbookView or %NULL
- * on error.
+ * Return value: (transfer full) (nullable): the newly allocated WorkbookView
+ * or %NULL on error.
  **/
 WorkbookView *
 workbook_view_new_from_input (GsfInput *input,
-                              const char *optional_uri,
-                              GOFileOpener const *optional_fmt,
+                              const char *uri,
+                              GOFileOpener const *file_opener,
                               GOIOContext *io_context,
-                              char const *optional_enc)
+                              char const *encoding)
 {
 	WorkbookView *new_wbv = NULL;
 
 	g_return_val_if_fail (GSF_IS_INPUT(input), NULL);
-	g_return_val_if_fail (optional_fmt == NULL ||
-			      GO_IS_FILE_OPENER (optional_fmt), NULL);
+	g_return_val_if_fail (file_opener == NULL ||
+			      GO_IS_FILE_OPENER (file_opener), NULL);
 
 	/* NOTE : we could support gzipped anything here if we wanted to
 	 * by adding a wrapper, but there is no framework for remembering that
-	 * the file was gzipped so lets not just yet.
+	 * the file was gzipped so let's not just yet.
 	 */
 
 	/* Search for an applicable opener */
-	if (optional_fmt == NULL) {
+	if (file_opener == NULL) {
 		GOFileProbeLevel pl;
 		GList *l;
 		int input_refs = G_OBJECT (input)->ref_count;
 
-		for (pl = GO_FILE_PROBE_FILE_NAME; pl < GO_FILE_PROBE_LAST && optional_fmt == NULL; pl++) {
+		for (pl = GO_FILE_PROBE_FILE_NAME; pl < GO_FILE_PROBE_LAST && file_opener == NULL; pl++) {
 			for (l = go_get_file_openers (); l != NULL; l = l->next) {
 				GOFileOpener const *tmp_fo = GO_FILE_OPENER (l->data);
 				int new_input_refs;
@@ -1247,7 +1344,7 @@ workbook_view_new_from_input (GsfInput *input,
 				    (pl == GO_FILE_PROBE_CONTENT ||
 				     !go_file_opener_can_probe	(tmp_fo, GO_FILE_PROBE_CONTENT) ||
 				     go_file_opener_probe (tmp_fo, input, GO_FILE_PROBE_CONTENT)))
-					optional_fmt = tmp_fo;
+					file_opener = tmp_fo;
 
 				new_input_refs = G_OBJECT (input)->ref_count;
 				if (new_input_refs != input_refs) {
@@ -1258,24 +1355,31 @@ workbook_view_new_from_input (GsfInput *input,
 					input_refs = new_input_refs;
 				}
 
-				if (optional_fmt)
+				if (file_opener)
 					break;
 			}
 		}
 	}
 
-	if (optional_fmt != NULL) {
+	if (file_opener != NULL) {
 		Workbook *new_wb;
 		gboolean old;
+		GDateTime *modtime;
 
 		new_wbv = workbook_view_new (NULL);
 		new_wb = wb_view_get_workbook (new_wbv);
-		if (optional_uri)
-			go_doc_set_uri (GO_DOC (new_wb), optional_uri);
+		if (uri)
+			go_doc_set_uri (GO_DOC (new_wb), uri);
+
+		// Grab the modtime before we actually do the reading
+		modtime = get_uri_modtime (input, uri);
+		go_doc_set_modtime (GO_DOC (new_wb), modtime);
+		if (modtime)
+			g_date_time_unref (modtime);
 
 		/* disable recursive dirtying while loading */
 		old = workbook_enable_recursive_dirty (new_wb, FALSE);
-		go_file_opener_open (optional_fmt, optional_enc, io_context,
+		go_file_opener_open (file_opener, encoding, io_context,
 		                     GO_VIEW (new_wbv), input);
 		workbook_enable_recursive_dirty (new_wb, old);
 
@@ -1294,13 +1398,16 @@ workbook_view_new_from_input (GsfInput *input,
 			workbook_recalc (new_wb);
 			workbook_update_graphs (new_wb);
 			go_doc_set_dirty (GO_DOC (new_wb), FALSE);
-			if (optional_uri && workbook_get_file_exporter (new_wb))
+			if (uri && workbook_get_file_exporter (new_wb))
 				workbook_set_last_export_uri
-					(new_wb, g_strdup (optional_uri));
+					(new_wb, uri);
 		}
-	} else
-		go_cmd_context_error_import (GO_CMD_CONTEXT (io_context),
-			_("Unsupported file format."));
+	} else {
+		if (io_context)
+			go_cmd_context_error_import
+				(GO_CMD_CONTEXT (io_context),
+				 _("Unsupported file format."));
+	}
 
 	return new_wbv;
 }
@@ -1308,21 +1415,21 @@ workbook_view_new_from_input (GsfInput *input,
 /**
  * workbook_view_new_from_uri:
  * @uri: URI for file
- * @optional_format: (allow-none): Optional GOFileOpener
- * @io_context: Optional context to display errors.
- * @optional_encoding: Optional encoding for GOFileOpener that understand it
+ * @file_opener: (allow-none): #GOFileOpener
+ * @io_context: Context to display errors.
+ * @encoding: (allow-none): Encoding for @file_opener that understands it
  *
- * Reads @uri file using given file opener @optional_fmt, or probes for a valid
- * possibility if @optional_fmt is NULL.  Reports problems to @io_context.
+ * Reads @uri file using given file opener @file_opener, or probes for a valid
+ * possibility if @file_opener is %NULL.  Reports problems to @io_context.
  *
- * Return value: (transfer full): the newly allocated WorkbookView or %NULL
- * on error.
+ * Return value: (transfer full) (nullable): the newly allocated WorkbookView
+ * or %NULL on error.
  **/
 WorkbookView *
 workbook_view_new_from_uri (char const *uri,
-		      GOFileOpener const *optional_fmt,
-		      GOIOContext *io_context,
-		      char const *optional_enc)
+			    GOFileOpener const *file_opener,
+			    GOIOContext *io_context,
+			    char const *encoding)
 {
 	char *msg = NULL;
 	GError *err = NULL;
@@ -1335,8 +1442,8 @@ workbook_view_new_from_uri (char const *uri,
 		WorkbookView *res;
 
 		res = workbook_view_new_from_input (input, uri,
-					      optional_fmt, io_context,
-					      optional_enc);
+						    file_opener, io_context,
+						    encoding);
 		g_object_unref (input);
 		return res;
 	}
@@ -1351,7 +1458,8 @@ workbook_view_new_from_uri (char const *uri,
 		msg = g_strdup_printf (_("An unexplained error happened while opening %s"),
 				       uri);
 
-	go_cmd_context_error_import (GO_CMD_CONTEXT (io_context), msg);
+	if (io_context)
+		go_cmd_context_error_import (GO_CMD_CONTEXT (io_context), msg);
 	g_free (msg);
 
 	return NULL;
